#[allow(dead_code)]

/// 半角・全角の変換対象として数値を設定する際のビットフラグです。
pub const CONVERT_TARGET_NUMBER: u32 = 0b00000001;
/// 半角・全角の変換対象としてアルファベットを設定する際のビットフラグです。
pub const CONVERT_TARGET_ALPHABET: u32 = 0b00000010;
/// 半角・全角の変換対象として記号を設定する際のビットフラグです。
pub const CONVERT_TARGET_SYMBOL: u32 = 0b00000100;
/// 半角・全角の変換対象としてカタカナを設定する際のビットフラグです。
pub const CONVERT_TARGET_KATAKANA: u32 = 0b00001000;
/// 半角・全角の変換が可能なものはすべて変換します。
pub const CONVERT_TARGET_ALL: u32 = (CONVERT_TARGET_NUMBER | CONVERT_TARGET_ALPHABET | CONVERT_TARGET_SYMBOL | CONVERT_TARGET_KATAKANA);

/// 大文字への変換を行う際に設定する値です。
pub const CONVERT_TYPE_UPPER_CASE: u32 = 1;
/// 小文字への変換を行う際に設定する値です。
pub const CONVERT_TYPE_LOWER_CASE: u32 = 2;
/// ひらがなへの変換を行う際に設定する値です。
pub const CONVERT_TYPE_HIRAGANA: u32 = 3;
/// カタカナへの変換を行う際に設定する値です。
pub const CONVERT_TYPE_KATAKANA: u32 = 4;
/// 半角文字への変換を行う際に設定する値です。
pub const CONVERT_TYPE_NARROW: u32 = 5;
/// 全角文字への変換を行う際に設定する値です。
pub const CONVERT_TYPE_WIDE: u32 = 6;
/// 変換を行わない際に設定する値です。
pub const CONVERT_TYPE_NONE: u32 = 0;

/// 半角 ASCII文字 記号 SPACE
pub const NARROW_ASCII_SYMBOL_SPACE: u32 = 0x0020;
/// 半角 ASCII文字 記号 EXCLAMATION_MARK
pub const NARROW_ASCII_SYMBOL_EXCLAMATION_MARK: u32 = 0x0021;
/// 半角 ASCII文字 記号 QUOTATION_MARK
pub const NARROW_ASCII_SYMBOL_QUOTATION_MARK: u32 = 0x0022;
/// 半角 ASCII文字 記号 NUMBER_SIGN
pub const NARROW_ASCII_SYMBOL_NUMBER_SIGN: u32 = 0x0023;
/// 半角 ASCII文字 記号 DOLLAR_SIGN
pub const NARROW_ASCII_SYMBOL_DOLLAR_SIGN: u32 = 0x0024;
/// 半角 ASCII文字 記号 PERCENT_SIGN
pub const NARROW_ASCII_SYMBOL_PERCENT_SIGN: u32 = 0x0025;
/// 半角 ASCII文字 記号 AMPERSAND
pub const NARROW_ASCII_SYMBOL_AMPERSAND: u32 = 0x0026;
/// 半角 ASCII文字 記号 APOSTROPHE
pub const NARROW_ASCII_SYMBOL_APOSTROPHE: u32 = 0x0027;
/// 半角 ASCII文字 記号 LEFT_PARENTHESIS
pub const NARROW_ASCII_SYMBOL_LEFT_PARENTHESIS: u32 = 0x0028;
/// 半角 ASCII文字 記号 RIGHT_PARENTHESIS
pub const NARROW_ASCII_SYMBOL_RIGHT_PARENTHESIS: u32 = 0x0029;
/// 半角 ASCII文字 記号 ASTERISK
pub const NARROW_ASCII_SYMBOL_ASTERISK: u32 = 0x002A;
/// 半角 ASCII文字 記号 PLUS_SIGN
pub const NARROW_ASCII_SYMBOL_PLUS_SIGN: u32 = 0x002B;
/// 半角 ASCII文字 記号 COMMA
pub const NARROW_ASCII_SYMBOL_COMMA: u32 = 0x002C;
/// 半角 ASCII文字 記号 HYPHEN-MINUS
pub const NARROW_ASCII_SYMBOL_HYPHEN_MINUS: u32 = 0x002D;
/// 半角 ASCII文字 記号 FULL_STOP
pub const NARROW_ASCII_SYMBOL_FULL_STOP: u32 = 0x002E;
/// 半角 ASCII文字 記号 SOLIDUS
pub const NARROW_ASCII_SYMBOL_SOLIDUS: u32 = 0x002F;
/// 半角 ASCII文字 数値 0
pub const NARROW_ASCII_NUMBER_0: u32 = 0x0030;
/// 半角 ASCII文字 数値 1
pub const NARROW_ASCII_NUMBER_1: u32 = 0x0031;
/// 半角 ASCII文字 数値 2
pub const NARROW_ASCII_NUMBER_2: u32 = 0x0032;
/// 半角 ASCII文字 数値 3
pub const NARROW_ASCII_NUMBER_3: u32 = 0x0033;
/// 半角 ASCII文字 数値 4
pub const NARROW_ASCII_NUMBER_4: u32 = 0x0034;
/// 半角 ASCII文字 数値 5
pub const NARROW_ASCII_NUMBER_5: u32 = 0x0035;
/// 半角 ASCII文字 数値 6
pub const NARROW_ASCII_NUMBER_6: u32 = 0x0036;
/// 半角 ASCII文字 数値 7
pub const NARROW_ASCII_NUMBER_7: u32 = 0x0037;
/// 半角 ASCII文字 数値 8
pub const NARROW_ASCII_NUMBER_8: u32 = 0x0038;
/// 半角 ASCII文字 数値 9
pub const NARROW_ASCII_NUMBER_9: u32 = 0x0039;
/// 半角 ASCII文字 記号 COLON
pub const NARROW_ASCII_SYMBOL_COLON: u32 = 0x003A;
/// 半角 ASCII文字 記号 SEMICOLON
pub const NARROW_ASCII_SYMBOL_SEMICOLON: u32 = 0x003B;
/// 半角 ASCII文字 記号 LESS-THAN_SIGN
pub const NARROW_ASCII_SYMBOL_LESS_THAN_SIGN: u32 = 0x003C;
/// 半角 ASCII文字 記号 EQUALS_SIGN
pub const NARROW_ASCII_SYMBOL_EQUALS_SIGN: u32 = 0x003D;
/// 半角 ASCII文字 記号 GREATER-THAN_SIGN
pub const NARROW_ASCII_SYMBOL_GREATER_THAN_SIGN: u32 = 0x003E;
/// 半角 ASCII文字 記号 QUESTION_MARK
pub const NARROW_ASCII_SYMBOL_QUESTION_MARK: u32 = 0x003F;
/// 半角 ASCII文字 記号 COMMERCIAL_AT
pub const NARROW_ASCII_SYMBOL_COMMERCIAL_AT: u32 = 0x0040;
/// 半角 ASCII文字 アルファベット大文字 A
pub const NARROW_ASCII_LATIN_UPPER_CASE_A: u32 = 0x0041;
/// 半角 ASCII文字 アルファベット大文字 B
pub const NARROW_ASCII_LATIN_UPPER_CASE_B: u32 = 0x0042;
/// 半角 ASCII文字 アルファベット大文字 C
pub const NARROW_ASCII_LATIN_UPPER_CASE_C: u32 = 0x0043;
/// 半角 ASCII文字 アルファベット大文字 D
pub const NARROW_ASCII_LATIN_UPPER_CASE_D: u32 = 0x0044;
/// 半角 ASCII文字 アルファベット大文字 E
pub const NARROW_ASCII_LATIN_UPPER_CASE_E: u32 = 0x0045;
/// 半角 ASCII文字 アルファベット大文字 F
pub const NARROW_ASCII_LATIN_UPPER_CASE_F: u32 = 0x0046;
/// 半角 ASCII文字 アルファベット大文字 G
pub const NARROW_ASCII_LATIN_UPPER_CASE_G: u32 = 0x0047;
/// 半角 ASCII文字 アルファベット大文字 H
pub const NARROW_ASCII_LATIN_UPPER_CASE_H: u32 = 0x0048;
/// 半角 ASCII文字 アルファベット大文字 I
pub const NARROW_ASCII_LATIN_UPPER_CASE_I: u32 = 0x0049;
/// 半角 ASCII文字 アルファベット大文字 J
pub const NARROW_ASCII_LATIN_UPPER_CASE_J: u32 = 0x004A;
/// 半角 ASCII文字 アルファベット大文字 K
pub const NARROW_ASCII_LATIN_UPPER_CASE_K: u32 = 0x004B;
/// 半角 ASCII文字 アルファベット大文字 L
pub const NARROW_ASCII_LATIN_UPPER_CASE_L: u32 = 0x004C;
/// 半角 ASCII文字 アルファベット大文字 M
pub const NARROW_ASCII_LATIN_UPPER_CASE_M: u32 = 0x004D;
/// 半角 ASCII文字 アルファベット大文字 N
pub const NARROW_ASCII_LATIN_UPPER_CASE_N: u32 = 0x004E;
/// 半角 ASCII文字 アルファベット大文字 O
pub const NARROW_ASCII_LATIN_UPPER_CASE_O: u32 = 0x004F;
/// 半角 ASCII文字 アルファベット大文字 P
pub const NARROW_ASCII_LATIN_UPPER_CASE_P: u32 = 0x0050;
/// 半角 ASCII文字 アルファベット大文字 Q
pub const NARROW_ASCII_LATIN_UPPER_CASE_Q: u32 = 0x0051;
/// 半角 ASCII文字 アルファベット大文字 R
pub const NARROW_ASCII_LATIN_UPPER_CASE_R: u32 = 0x0052;
/// 半角 ASCII文字 アルファベット大文字 S
pub const NARROW_ASCII_LATIN_UPPER_CASE_S: u32 = 0x0053;
/// 半角 ASCII文字 アルファベット大文字 T
pub const NARROW_ASCII_LATIN_UPPER_CASE_T: u32 = 0x0054;
/// 半角 ASCII文字 アルファベット大文字 U
pub const NARROW_ASCII_LATIN_UPPER_CASE_U: u32 = 0x0055;
/// 半角 ASCII文字 アルファベット大文字 V
pub const NARROW_ASCII_LATIN_UPPER_CASE_V: u32 = 0x0056;
/// 半角 ASCII文字 アルファベット大文字 W
pub const NARROW_ASCII_LATIN_UPPER_CASE_W: u32 = 0x0057;
/// 半角 ASCII文字 アルファベット大文字 X
pub const NARROW_ASCII_LATIN_UPPER_CASE_X: u32 = 0x0058;
/// 半角 ASCII文字 アルファベット大文字 Y
pub const NARROW_ASCII_LATIN_UPPER_CASE_Y: u32 = 0x0059;
/// 半角 ASCII文字 アルファベット大文字 Z
pub const NARROW_ASCII_LATIN_UPPER_CASE_Z: u32 = 0x005A;
/// 半角 ASCII文字 記号 LEFT_SQUARE_BRACKET
pub const NARROW_ASCII_SYMBOL_LEFT_SQUARE_BRACKET: u32 = 0x005B;
/// 半角 ASCII文字 記号 REVERSE_SOLIDUS
pub const NARROW_ASCII_SYMBOL_REVERSE_SOLIDUS: u32 = 0x005C;
/// 半角 ASCII文字 記号 RIGHT_SQUARE_BRACKET
pub const NARROW_ASCII_SYMBOL_RIGHT_SQUARE_BRACKET: u32 = 0x005D;
/// 半角 ASCII文字 記号 CIRCUMFLEX_ACCENT
pub const NARROW_ASCII_SYMBOL_CIRCUMFLEX_ACCENT: u32 = 0x005E;
/// 半角 ASCII文字 記号 LOW_LINE
pub const NARROW_ASCII_SYMBOL_LOW_LINE: u32 = 0x005F;
/// 半角 ASCII文字 記号 GRAVE_ACCENT
pub const NARROW_ASCII_SYMBOL_GRAVE_ACCENT: u32 = 0x0060;
/// 半角 ASCII文字 アルファベット小文字 A
pub const NARROW_ASCII_LATIN_LOWER_CASE_A: u32 = 0x0061;
/// 半角 ASCII文字 アルファベット小文字 B
pub const NARROW_ASCII_LATIN_LOWER_CASE_B: u32 = 0x0062;
/// 半角 ASCII文字 アルファベット小文字 C
pub const NARROW_ASCII_LATIN_LOWER_CASE_C: u32 = 0x0063;
/// 半角 ASCII文字 アルファベット小文字 D
pub const NARROW_ASCII_LATIN_LOWER_CASE_D: u32 = 0x0064;
/// 半角 ASCII文字 アルファベット小文字 E
pub const NARROW_ASCII_LATIN_LOWER_CASE_E: u32 = 0x0065;
/// 半角 ASCII文字 アルファベット小文字 F
pub const NARROW_ASCII_LATIN_LOWER_CASE_F: u32 = 0x0066;
/// 半角 ASCII文字 アルファベット小文字 G
pub const NARROW_ASCII_LATIN_LOWER_CASE_G: u32 = 0x0067;
/// 半角 ASCII文字 アルファベット小文字 H
pub const NARROW_ASCII_LATIN_LOWER_CASE_H: u32 = 0x0068;
/// 半角 ASCII文字 アルファベット小文字 I
pub const NARROW_ASCII_LATIN_LOWER_CASE_I: u32 = 0x0069;
/// 半角 ASCII文字 アルファベット小文字 J
pub const NARROW_ASCII_LATIN_LOWER_CASE_J: u32 = 0x006A;
/// 半角 ASCII文字 アルファベット小文字 K
pub const NARROW_ASCII_LATIN_LOWER_CASE_K: u32 = 0x006B;
/// 半角 ASCII文字 アルファベット小文字 L
pub const NARROW_ASCII_LATIN_LOWER_CASE_L: u32 = 0x006C;
/// 半角 ASCII文字 アルファベット小文字 M
pub const NARROW_ASCII_LATIN_LOWER_CASE_M: u32 = 0x006D;
/// 半角 ASCII文字 アルファベット小文字 N
pub const NARROW_ASCII_LATIN_LOWER_CASE_N: u32 = 0x006E;
/// 半角 ASCII文字 アルファベット小文字 O
pub const NARROW_ASCII_LATIN_LOWER_CASE_O: u32 = 0x006F;
/// 半角 ASCII文字 アルファベット小文字 P
pub const NARROW_ASCII_LATIN_LOWER_CASE_P: u32 = 0x0070;
/// 半角 ASCII文字 アルファベット小文字 Q
pub const NARROW_ASCII_LATIN_LOWER_CASE_Q: u32 = 0x0071;
/// 半角 ASCII文字 アルファベット小文字 R
pub const NARROW_ASCII_LATIN_LOWER_CASE_R: u32 = 0x0072;
/// 半角 ASCII文字 アルファベット小文字 S
pub const NARROW_ASCII_LATIN_LOWER_CASE_S: u32 = 0x0073;
/// 半角 ASCII文字 アルファベット小文字 T
pub const NARROW_ASCII_LATIN_LOWER_CASE_T: u32 = 0x0074;
/// 半角 ASCII文字 アルファベット小文字 U
pub const NARROW_ASCII_LATIN_LOWER_CASE_U: u32 = 0x0075;
/// 半角 ASCII文字 アルファベット小文字 V
pub const NARROW_ASCII_LATIN_LOWER_CASE_V: u32 = 0x0076;
/// 半角 ASCII文字 アルファベット小文字 W
pub const NARROW_ASCII_LATIN_LOWER_CASE_W: u32 = 0x0077;
/// 半角 ASCII文字 アルファベット小文字 X
pub const NARROW_ASCII_LATIN_LOWER_CASE_X: u32 = 0x0078;
/// 半角 ASCII文字 アルファベット小文字 Y
pub const NARROW_ASCII_LATIN_LOWER_CASE_Y: u32 = 0x0079;
/// 半角 ASCII文字 アルファベット小文字 Z
pub const NARROW_ASCII_LATIN_LOWER_CASE_Z: u32 = 0x007A;
/// 半角 ASCII文字 記号 LEFT_CURLY_BRACKET
pub const NARROW_ASCII_SYMBOL_LEFT_CURLY_BRACKET: u32 = 0x007B;
/// 半角 ASCII文字 記号 VERTICAL_LINE
pub const NARROW_ASCII_SYMBOL_VERTICAL_LINE: u32 = 0x007C;
/// 半角 ASCII文字 記号 RIGHT_CURLY_BRACKET
pub const NARROW_ASCII_SYMBOL_RIGHT_CURLY_BRACKET: u32 = 0x007D;
/// 半角 ASCII文字 記号 TILDE
pub const NARROW_ASCII_SYMBOL_TILDE: u32 = 0x007E;
/// 半角 JIS 記号 NO_BREAK_SPACE
pub const NARROW_JIS_SYMBOL_NO_BREAK_SPACE: u32 = 0x00a0;
/// 半角 JIS 記号 INVERTED_EXCLAMATION_MARK
pub const NARROW_JIS_SYMBOL_INVERTED_EXCLAMATION_MARK: u32 = 0x00a1;
/// 半角 JIS 記号 CENT_SIGN
pub const NARROW_JIS_SYMBOL_CENT_SIGN: u32 = 0x00A2;
/// 半角 JIS 記号 POUND_SIGN
pub const NARROW_JIS_SYMBOL_POUND_SIGN: u32 = 0x00A3;
/// 半角 JIS 記号 CURRENCY_SIGN
pub const NARROW_JIS_SYMBOL_CURRENCY_SIGN: u32 = 0x00a4;
/// 半角 JIS 記号 YEN_SIGN
pub const NARROW_JIS_SYMBOL_YEN_SIGN: u32 = 0x00A5;
/// 半角 JIS 記号 BROKEN_BAR
pub const NARROW_JIS_SYMBOL_BROKEN_BAR: u32 = 0x00A6;
/// 全角 JIS 記号 SECTION_SIGN
pub const WIDE_JIS_SYMBOL_SECTION_SIGN: u32 = 0x00a7;
/// 全角 JIS 記号 DIAERESIS
pub const WIDE_JIS_SYMBOL_DIAERESIS: u32 = 0x00a8;
/// 半角 JIS 記号 COPYRIGHT_SIGN
pub const NARROW_JIS_SYMBOL_COPYRIGHT_SIGN: u32 = 0x00a9;
/// 半角 JIS 記号 FEMININE_ORDINAL_INDICATOR
pub const NARROW_JIS_SYMBOL_FEMININE_ORDINAL_INDICATOR: u32 = 0x00aa;
/// 全角 JIS 記号 LEFT_POINTING_DOUBLE_ANGLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_LEFT_POINTING_DOUBLE_ANGLE_QUOTATION_MARK: u32 = 0x00ab;
/// 半角 JIS 記号 NOT_SIGN
pub const NARROW_JIS_SYMBOL_NOT_SIGN: u32 = 0x00AC;
/// 半角 JIS 記号 SOFT_HYPHEN
pub const NARROW_JIS_SYMBOL_SOFT_HYPHEN: u32 = 0x00ad;
/// 半角 JIS 記号 REGISTERED_SIGN
pub const NARROW_JIS_SYMBOL_REGISTERED_SIGN: u32 = 0x00ae;
/// 半角 JIS 記号 MACRON
pub const NARROW_JIS_SYMBOL_MACRON: u32 = 0x00AF;
/// 全角 JIS 記号 DEGREE_SIGN
pub const WIDE_JIS_SYMBOL_DEGREE_SIGN: u32 = 0x00b0;
/// 全角 JIS 記号 PLUS_MINUS_SIGN
pub const WIDE_JIS_SYMBOL_PLUS_MINUS_SIGN: u32 = 0x00b1;
/// 半角 JIS 記号 SUPERSCRIPT_TWO
pub const NARROW_JIS_SYMBOL_SUPERSCRIPT_TWO: u32 = 0x00b2;
/// 半角 JIS 記号 SUPERSCRIPT_THREE
pub const NARROW_JIS_SYMBOL_SUPERSCRIPT_THREE: u32 = 0x00b3;
/// 全角 JIS 記号 ACUTE_ACCENT
pub const WIDE_JIS_SYMBOL_ACUTE_ACCENT: u32 = 0x00b4;
/// 全角 JIS 記号 PILCROW_SIGN
pub const WIDE_JIS_SYMBOL_PILCROW_SIGN: u32 = 0x00b6;
/// 全角 JIS 記号 MIDDLE_DOT
pub const WIDE_JIS_SYMBOL_MIDDLE_DOT: u32 = 0x00b7;
/// 全角 JIS 記号 CEDILLA
pub const WIDE_JIS_SYMBOL_CEDILLA: u32 = 0x00b8;
/// 半角 JIS 記号 SUPERSCRIPT_ONE
pub const NARROW_JIS_SYMBOL_SUPERSCRIPT_ONE: u32 = 0x00b9;
/// 半角 JIS 記号 MASCULINE_ORDINAL_INDICATOR
pub const NARROW_JIS_SYMBOL_MASCULINE_ORDINAL_INDICATOR: u32 = 0x00ba;
/// 全角 JIS 記号 RIGHT_POINTING_DOUBLE_ANGLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_RIGHT_POINTING_DOUBLE_ANGLE_QUOTATION_MARK: u32 = 0x00bb;
/// 半角 JIS 記号 VULGAR_FRACTION_ONE_QUARTER
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_ONE_QUARTER: u32 = 0x00bc;
/// 半角 JIS 記号 VULGAR_FRACTION_ONE_HALF
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_ONE_HALF: u32 = 0x00bd;
/// 半角 JIS 記号 VULGAR_FRACTION_THREE_QUARTERS
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_THREE_QUARTERS: u32 = 0x00be;
/// 半角 JIS 記号 INVERTED_QUESTION_MARK
pub const NARROW_JIS_SYMBOL_INVERTED_QUESTION_MARK: u32 = 0x00bf;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_GRAVE: u32 = 0x00c0;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_ACUTE: u32 = 0x00c1;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_CIRCUMFLEX: u32 = 0x00c2;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_TILDE: u32 = 0x00c3;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_DIAERESIS: u32 = 0x00c4;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_RING_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_RING_ABOVE: u32 = 0x00c5;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_AE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_AE: u32 = 0x00c6;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_C_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_C_WITH_CEDILLA: u32 = 0x00c7;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_GRAVE: u32 = 0x00c8;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_ACUTE: u32 = 0x00c9;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_CIRCUMFLEX: u32 = 0x00ca;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_DIAERESIS: u32 = 0x00cb;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_I_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_I_WITH_GRAVE: u32 = 0x00cc;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_I_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_I_WITH_ACUTE: u32 = 0x00cd;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_I_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_I_WITH_CIRCUMFLEX: u32 = 0x00ce;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_I_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_I_WITH_DIAERESIS: u32 = 0x00cf;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_ETH
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_ETH: u32 = 0x00d0;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_N_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_N_WITH_TILDE: u32 = 0x00d1;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_GRAVE: u32 = 0x00d2;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_ACUTE: u32 = 0x00d3;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_CIRCUMFLEX: u32 = 0x00d4;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_TILDE: u32 = 0x00d5;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_DIAERESIS: u32 = 0x00d6;
/// 全角 JIS 記号 MULTIPLICATION_SIGN
pub const WIDE_JIS_SYMBOL_MULTIPLICATION_SIGN: u32 = 0x00d7;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_STROKE: u32 = 0x00d8;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_GRAVE: u32 = 0x00d9;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_ACUTE: u32 = 0x00da;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_CIRCUMFLEX: u32 = 0x00db;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_DIAERESIS: u32 = 0x00dc;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_Y_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_Y_WITH_ACUTE: u32 = 0x00dd;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_THORN
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_THORN: u32 = 0x00de;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_SHARP_S
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_SHARP_S: u32 = 0x00df;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_GRAVE: u32 = 0x00e0;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_ACUTE: u32 = 0x00e1;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_CIRCUMFLEX: u32 = 0x00e2;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_TILDE: u32 = 0x00e3;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_DIAERESIS: u32 = 0x00e4;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_RING_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_RING_ABOVE: u32 = 0x00e5;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_AE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_AE: u32 = 0x00e6;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_C_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_C_WITH_CEDILLA: u32 = 0x00e7;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_GRAVE: u32 = 0x00e8;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_ACUTE: u32 = 0x00e9;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_CIRCUMFLEX: u32 = 0x00ea;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_DIAERESIS: u32 = 0x00eb;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_GRAVE: u32 = 0x00ec;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_ACUTE: u32 = 0x00ed;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_CIRCUMFLEX: u32 = 0x00ee;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_DIAERESIS: u32 = 0x00ef;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_ETH
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_ETH: u32 = 0x00f0;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_TILDE: u32 = 0x00f1;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_GRAVE: u32 = 0x00f2;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_ACUTE: u32 = 0x00f3;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_CIRCUMFLEX: u32 = 0x00f4;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_TILDE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_TILDE: u32 = 0x00f5;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_DIAERESIS: u32 = 0x00f6;
/// 全角 JIS 記号 DIVISION_SIGN
pub const WIDE_JIS_SYMBOL_DIVISION_SIGN: u32 = 0x00f7;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_STROKE: u32 = 0x00f8;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_GRAVE: u32 = 0x00f9;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_ACUTE: u32 = 0x00fa;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_CIRCUMFLEX: u32 = 0x00fb;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DIAERESIS: u32 = 0x00fc;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Y_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Y_WITH_ACUTE: u32 = 0x00fd;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_THORN
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_THORN: u32 = 0x00fe;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Y_WITH_DIAERESIS
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Y_WITH_DIAERESIS: u32 = 0x00ff;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_MACRON: u32 = 0x0100;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_MACRON: u32 = 0x0101;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_BREVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_BREVE: u32 = 0x0102;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_BREVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_BREVE: u32 = 0x0103;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_OGONEK
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_OGONEK: u32 = 0x0104;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_OGONEK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_OGONEK: u32 = 0x0105;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_C_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_C_WITH_ACUTE: u32 = 0x0106;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_C_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_C_WITH_ACUTE: u32 = 0x0107;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_C_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_C_WITH_CIRCUMFLEX: u32 = 0x0108;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_C_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_C_WITH_CIRCUMFLEX: u32 = 0x0109;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_C_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_C_WITH_CARON: u32 = 0x010c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_C_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_C_WITH_CARON: u32 = 0x010d;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_D_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_D_WITH_CARON: u32 = 0x010e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_D_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_D_WITH_CARON: u32 = 0x010f;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_D_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_D_WITH_STROKE: u32 = 0x0111;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_MACRON: u32 = 0x0112;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_MACRON: u32 = 0x0113;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_OGONEK
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_OGONEK: u32 = 0x0118;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_OGONEK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_OGONEK: u32 = 0x0119;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_E_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_E_WITH_CARON: u32 = 0x011a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_E_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_E_WITH_CARON: u32 = 0x011b;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_G_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_G_WITH_CIRCUMFLEX: u32 = 0x011c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_G_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_G_WITH_CIRCUMFLEX: u32 = 0x011d;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_H_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_H_WITH_CIRCUMFLEX: u32 = 0x0124;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_H_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_H_WITH_CIRCUMFLEX: u32 = 0x0125;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_H_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_H_WITH_STROKE: u32 = 0x0127;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_I_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_I_WITH_MACRON: u32 = 0x012a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_MACRON: u32 = 0x012b;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_J_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_J_WITH_CIRCUMFLEX: u32 = 0x0134;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_J_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_J_WITH_CIRCUMFLEX: u32 = 0x0135;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_L_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_L_WITH_ACUTE: u32 = 0x0139;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_L_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_L_WITH_ACUTE: u32 = 0x013a;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_L_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_L_WITH_CARON: u32 = 0x013d;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_L_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_L_WITH_CARON: u32 = 0x013e;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_L_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_L_WITH_STROKE: u32 = 0x0141;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_L_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_L_WITH_STROKE: u32 = 0x0142;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_N_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_N_WITH_ACUTE: u32 = 0x0143;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_ACUTE: u32 = 0x0144;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_N_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_N_WITH_CARON: u32 = 0x0147;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_CARON: u32 = 0x0148;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_ENG
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_ENG: u32 = 0x014b;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_MACRON: u32 = 0x014c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_MACRON: u32 = 0x014d;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_DOUBLE_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_DOUBLE_ACUTE: u32 = 0x0150;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_DOUBLE_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_DOUBLE_ACUTE: u32 = 0x0151;
/// 半角 JIS 記号 LATIN_CAPITAL_LIGATURE_OE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LIGATURE_OE: u32 = 0x0152;
/// 半角 JIS 記号 LATIN_SMALL_LIGATURE_OE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LIGATURE_OE: u32 = 0x0153;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_R_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_R_WITH_ACUTE: u32 = 0x0154;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_R_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_R_WITH_ACUTE: u32 = 0x0155;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_R_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_R_WITH_CARON: u32 = 0x0158;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_R_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_R_WITH_CARON: u32 = 0x0159;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_S_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_S_WITH_ACUTE: u32 = 0x015a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_S_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_S_WITH_ACUTE: u32 = 0x015b;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_S_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_S_WITH_CIRCUMFLEX: u32 = 0x015c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_S_WITH_CIRCUMFLEX
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_S_WITH_CIRCUMFLEX: u32 = 0x015d;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_S_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_S_WITH_CEDILLA: u32 = 0x015e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_S_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_S_WITH_CEDILLA: u32 = 0x015f;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_S_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_S_WITH_CARON: u32 = 0x0160;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_S_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_S_WITH_CARON: u32 = 0x0161;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_T_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_T_WITH_CEDILLA: u32 = 0x0162;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_T_WITH_CEDILLA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_T_WITH_CEDILLA: u32 = 0x0163;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_T_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_T_WITH_CARON: u32 = 0x0164;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_T_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_T_WITH_CARON: u32 = 0x0165;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_MACRON: u32 = 0x016a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_MACRON: u32 = 0x016b;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_BREVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_BREVE: u32 = 0x016c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_BREVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_BREVE: u32 = 0x016d;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_RING_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_RING_ABOVE: u32 = 0x016e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_RING_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_RING_ABOVE: u32 = 0x016f;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_U_WITH_DOUBLE_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_U_WITH_DOUBLE_ACUTE: u32 = 0x0170;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DOUBLE_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DOUBLE_ACUTE: u32 = 0x0171;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_Z_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_Z_WITH_ACUTE: u32 = 0x0179;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Z_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Z_WITH_ACUTE: u32 = 0x017a;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_Z_WITH_DOT_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_Z_WITH_DOT_ABOVE: u32 = 0x017b;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Z_WITH_DOT_ABOVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Z_WITH_DOT_ABOVE: u32 = 0x017c;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_Z_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_Z_WITH_CARON: u32 = 0x017d;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Z_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Z_WITH_CARON: u32 = 0x017e;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_G_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_G_WITH_HOOK: u32 = 0x0193;
/// 半角 JIS 記号 LATIN_LETTER_ALVEOLAR_CLICK
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_ALVEOLAR_CLICK: u32 = 0x01c2;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_A_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_A_WITH_CARON: u32 = 0x01cd;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_A_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_A_WITH_CARON: u32 = 0x01ce;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_CARON: u32 = 0x01d0;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_O_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_O_WITH_CARON: u32 = 0x01d1;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_O_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_O_WITH_CARON: u32 = 0x01d2;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_CARON: u32 = 0x01d4;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_MACRON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_MACRON: u32 = 0x01d6;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_ACUTE: u32 = 0x01d8;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_CARON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_CARON: u32 = 0x01da;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_WITH_DIAERESIS_AND_GRAVE: u32 = 0x01dc;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_N_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_N_WITH_GRAVE: u32 = 0x01f8;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_GRAVE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_GRAVE: u32 = 0x01f9;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_AE_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_AE_WITH_ACUTE: u32 = 0x01fd;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_A
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_A: u32 = 0x0250;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_ALPHA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_ALPHA: u32 = 0x0251;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_ALPHA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_ALPHA: u32 = 0x0252;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_B_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_B_WITH_HOOK: u32 = 0x0253;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_OPEN_O
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_OPEN_O: u32 = 0x0254;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_C_WITH_CURL
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_C_WITH_CURL: u32 = 0x0255;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_D_WITH_TAIL
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_D_WITH_TAIL: u32 = 0x0256;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_D_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_D_WITH_HOOK: u32 = 0x0257;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_REVERSED_E
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_REVERSED_E: u32 = 0x0258;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_SCHWA
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_SCHWA: u32 = 0x0259;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_SCHWA_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_SCHWA_WITH_HOOK: u32 = 0x025a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_REVERSED_OPEN_E
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_REVERSED_OPEN_E: u32 = 0x025c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_CLOSED_REVERSED_OPEN_E
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_CLOSED_REVERSED_OPEN_E: u32 = 0x025e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_DOTLESS_J_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_DOTLESS_J_WITH_STROKE: u32 = 0x025f;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_G_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_G_WITH_HOOK: u32 = 0x0260;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_SCRIPT_G
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_SCRIPT_G: u32 = 0x0261;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_RAMS_HORN
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_RAMS_HORN: u32 = 0x0264;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_H
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_H: u32 = 0x0265;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_H_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_H_WITH_HOOK: u32 = 0x0266;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_HENG_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_HENG_WITH_HOOK: u32 = 0x0267;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_I_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_I_WITH_STROKE: u32 = 0x0268;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_L_WITH_BELT
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_L_WITH_BELT: u32 = 0x026c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_L_WITH_RETROFLEX_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_L_WITH_RETROFLEX_HOOK: u32 = 0x026d;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_LEZH
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_LEZH: u32 = 0x026e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_M
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_M: u32 = 0x026f;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_M_WITH_LONG_LEG
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_M_WITH_LONG_LEG: u32 = 0x0270;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_M_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_M_WITH_HOOK: u32 = 0x0271;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_LEFT_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_LEFT_HOOK: u32 = 0x0272;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_N_WITH_RETROFLEX_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_N_WITH_RETROFLEX_HOOK: u32 = 0x0273;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_BARRED_O
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_BARRED_O: u32 = 0x0275;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_R
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_R: u32 = 0x0279;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_R_WITH_LONG_LEG
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_R_WITH_LONG_LEG: u32 = 0x027a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_R_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_R_WITH_HOOK: u32 = 0x027b;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_R_WITH_TAIL
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_R_WITH_TAIL: u32 = 0x027d;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_R_WITH_FISHHOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_R_WITH_FISHHOOK: u32 = 0x027e;
/// 半角 JIS 記号 LATIN_LETTER_SMALL_CAPITAL_INVERTED_R
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_SMALL_CAPITAL_INVERTED_R: u32 = 0x0281;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_S_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_S_WITH_HOOK: u32 = 0x0282;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_ESH
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_ESH: u32 = 0x0283;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_DOTLESS_J_WITH_STROKE_AND_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_DOTLESS_J_WITH_STROKE_AND_HOOK: u32 = 0x0284;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_T_WITH_RETROFLEX_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_T_WITH_RETROFLEX_HOOK: u32 = 0x0288;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_U_BAR
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_U_BAR: u32 = 0x0289;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_UPSILON
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_UPSILON: u32 = 0x028a;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_V_WITH_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_V_WITH_HOOK: u32 = 0x028b;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_V
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_V: u32 = 0x028c;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_W
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_W: u32 = 0x028d;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_TURNED_Y
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_TURNED_Y: u32 = 0x028e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Z_WITH_RETROFLEX_HOOK
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Z_WITH_RETROFLEX_HOOK: u32 = 0x0290;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_Z_WITH_CURL
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_Z_WITH_CURL: u32 = 0x0291;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_EZH
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_EZH: u32 = 0x0292;
/// 半角 JIS 記号 LATIN_LETTER_GLOTTAL_STOP
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_GLOTTAL_STOP: u32 = 0x0294;
/// 半角 JIS 記号 LATIN_LETTER_PHARYNGEAL_VOICED_FRICATIVE
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_PHARYNGEAL_VOICED_FRICATIVE: u32 = 0x0295;
/// 半角 JIS 記号 LATIN_LETTER_BILABIAL_CLICK
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_BILABIAL_CLICK: u32 = 0x0298;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_J_WITH_CROSSED_TAIL
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_J_WITH_CROSSED_TAIL: u32 = 0x029d;
/// 半角 JIS 記号 LATIN_LETTER_GLOTTAL_STOP_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_GLOTTAL_STOP_WITH_STROKE: u32 = 0x02a1;
/// 半角 JIS 記号 LATIN_LETTER_REVERSED_GLOTTAL_STOP_WITH_STROKE
pub const NARROW_JIS_SYMBOL_LATIN_LETTER_REVERSED_GLOTTAL_STOP_WITH_STROKE: u32 = 0x02a2;
/// 半角 JIS 記号 CARON
pub const NARROW_JIS_SYMBOL_CARON: u32 = 0x02c7;
/// 半角 JIS 記号 MODIFIER_LETTER_VERTICAL_LINE
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_VERTICAL_LINE: u32 = 0x02c8;
/// 半角 JIS 記号 MODIFIER_LETTER_LOW_VERTICAL_LINE
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_LOW_VERTICAL_LINE: u32 = 0x02cc;
/// 半角 JIS 記号 MODIFIER_LETTER_TRIANGULAR_COLON
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_TRIANGULAR_COLON: u32 = 0x02d0;
/// 半角 JIS 記号 MODIFIER_LETTER_HALF_TRIANGULAR_COLON
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_HALF_TRIANGULAR_COLON: u32 = 0x02d1;
/// 半角 JIS 記号 BREVE
pub const NARROW_JIS_SYMBOL_BREVE: u32 = 0x02d8;
/// 半角 JIS 記号 DOT_ABOVE
pub const NARROW_JIS_SYMBOL_DOT_ABOVE: u32 = 0x02d9;
/// 半角 JIS 記号 OGONEK
pub const NARROW_JIS_SYMBOL_OGONEK: u32 = 0x02db;
/// 半角 JIS 記号 DOUBLE_ACUTE_ACCENT
pub const NARROW_JIS_SYMBOL_DOUBLE_ACUTE_ACCENT: u32 = 0x02dd;
/// 半角 JIS 記号 MODIFIER_LETTER_RHOTIC_HOOK
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_RHOTIC_HOOK: u32 = 0x02de;
/// 半角 JIS 記号 MODIFIER_LETTER_EXTRA_HIGH_TONE_BAR
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_EXTRA_HIGH_TONE_BAR: u32 = 0x02e5;
/// 半角 JIS 記号 MODIFIER_LETTER_HIGH_TONE_BAR
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_HIGH_TONE_BAR: u32 = 0x02e6;
/// 半角 JIS 記号 MODIFIER_LETTER_MID_TONE_BAR
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_MID_TONE_BAR: u32 = 0x02e7;
/// 半角 JIS 記号 MODIFIER_LETTER_LOW_TONE_BAR
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_LOW_TONE_BAR: u32 = 0x02e8;
/// 半角 JIS 記号 MODIFIER_LETTER_EXTRA_LOW_TONE_BAR
pub const NARROW_JIS_SYMBOL_MODIFIER_LETTER_EXTRA_LOW_TONE_BAR: u32 = 0x02e9;
/// 半角 JIS 記号 COMBINING_GRAVE_ACCENT
pub const NARROW_JIS_SYMBOL_COMBINING_GRAVE_ACCENT: u32 = 0x0300;
/// 半角 JIS 記号 COMBINING_ACUTE_ACCENT
pub const NARROW_JIS_SYMBOL_COMBINING_ACUTE_ACCENT: u32 = 0x0301;
/// 半角 JIS 記号 COMBINING_CIRCUMFLEX_ACCENT
pub const NARROW_JIS_SYMBOL_COMBINING_CIRCUMFLEX_ACCENT: u32 = 0x0302;
/// 半角 JIS 記号 COMBINING_TILDE
pub const NARROW_JIS_SYMBOL_COMBINING_TILDE: u32 = 0x0303;
/// 半角 JIS 記号 COMBINING_MACRON
pub const NARROW_JIS_SYMBOL_COMBINING_MACRON: u32 = 0x0304;
/// 半角 JIS 記号 COMBINING_BREVE
pub const NARROW_JIS_SYMBOL_COMBINING_BREVE: u32 = 0x0306;
/// 半角 JIS 記号 COMBINING_DIAERESIS
pub const NARROW_JIS_SYMBOL_COMBINING_DIAERESIS: u32 = 0x0308;
/// 半角 JIS 記号 COMBINING_DOUBLE_ACUTE_ACCENT
pub const NARROW_JIS_SYMBOL_COMBINING_DOUBLE_ACUTE_ACCENT: u32 = 0x030b;
/// 半角 JIS 記号 COMBINING_CARON
pub const NARROW_JIS_SYMBOL_COMBINING_CARON: u32 = 0x030c;
/// 半角 JIS 記号 COMBINING_DOUBLE_GRAVE_ACCENT
pub const NARROW_JIS_SYMBOL_COMBINING_DOUBLE_GRAVE_ACCENT: u32 = 0x030f;
/// 半角 JIS 記号 COMBINING_LEFT_TACK_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_LEFT_TACK_BELOW: u32 = 0x0318;
/// 半角 JIS 記号 COMBINING_RIGHT_TACK_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_RIGHT_TACK_BELOW: u32 = 0x0319;
/// 半角 JIS 記号 COMBINING_LEFT_ANGLE_ABOVE
pub const NARROW_JIS_SYMBOL_COMBINING_LEFT_ANGLE_ABOVE: u32 = 0x031a;
/// 半角 JIS 記号 COMBINING_LEFT_HALF_RING_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_LEFT_HALF_RING_BELOW: u32 = 0x031c;
/// 半角 JIS 記号 COMBINING_UP_TACK_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_UP_TACK_BELOW: u32 = 0x031d;
/// 半角 JIS 記号 COMBINING_DOWN_TACK_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_DOWN_TACK_BELOW: u32 = 0x031e;
/// 半角 JIS 記号 COMBINING_PLUS_SIGN_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_PLUS_SIGN_BELOW: u32 = 0x031f;
/// 半角 JIS 記号 COMBINING_MINUS_SIGN_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_MINUS_SIGN_BELOW: u32 = 0x0320;
/// 半角 JIS 記号 COMBINING_DIAERESIS_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_DIAERESIS_BELOW: u32 = 0x0324;
/// 半角 JIS 記号 COMBINING_RING_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_RING_BELOW: u32 = 0x0325;
/// 半角 JIS 記号 COMBINING_VERTICAL_LINE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_VERTICAL_LINE_BELOW: u32 = 0x0329;
/// 半角 JIS 記号 COMBINING_BRIDGE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_BRIDGE_BELOW: u32 = 0x032a;
/// 半角 JIS 記号 COMBINING_CARON_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_CARON_BELOW: u32 = 0x032c;
/// 半角 JIS 記号 COMBINING_INVERTED_BREVE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_INVERTED_BREVE_BELOW: u32 = 0x032f;
/// 半角 JIS 記号 COMBINING_TILDE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_TILDE_BELOW: u32 = 0x0330;
/// 半角 JIS 記号 COMBINING_TILDE_OVERLAY
pub const NARROW_JIS_SYMBOL_COMBINING_TILDE_OVERLAY: u32 = 0x0334;
/// 半角 JIS 記号 COMBINING_RIGHT_HALF_RING_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_RIGHT_HALF_RING_BELOW: u32 = 0x0339;
/// 半角 JIS 記号 COMBINING_INVERTED_BRIDGE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_INVERTED_BRIDGE_BELOW: u32 = 0x033a;
/// 半角 JIS 記号 COMBINING_SQUARE_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_SQUARE_BELOW: u32 = 0x033b;
/// 半角 JIS 記号 COMBINING_SEAGULL_BELOW
pub const NARROW_JIS_SYMBOL_COMBINING_SEAGULL_BELOW: u32 = 0x033c;
/// 半角 JIS 記号 COMBINING_X_ABOVE
pub const NARROW_JIS_SYMBOL_COMBINING_X_ABOVE: u32 = 0x033d;
/// 半角 JIS 記号 COMBINING_DOUBLE_INVERTED_BREVE
pub const NARROW_JIS_SYMBOL_COMBINING_DOUBLE_INVERTED_BREVE: u32 = 0x0361;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_ALPHA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_ALPHA: u32 = 0x0391;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_BETA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_BETA: u32 = 0x0392;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_GAMMA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_GAMMA: u32 = 0x0393;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_DELTA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_DELTA: u32 = 0x0394;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_EPSILON
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_EPSILON: u32 = 0x0395;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_ZETA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_ZETA: u32 = 0x0396;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_ETA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_ETA: u32 = 0x0397;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_THETA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_THETA: u32 = 0x0398;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_IOTA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_IOTA: u32 = 0x0399;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_KAPPA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_KAPPA: u32 = 0x039a;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_LAMDA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_LAMDA: u32 = 0x039b;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_MU
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_MU: u32 = 0x039c;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_NU
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_NU: u32 = 0x039d;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_XI
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_XI: u32 = 0x039e;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_OMICRON
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_OMICRON: u32 = 0x039f;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_PI
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_PI: u32 = 0x03a0;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_RHO
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_RHO: u32 = 0x03a1;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_SIGMA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_SIGMA: u32 = 0x03a3;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_TAU
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_TAU: u32 = 0x03a4;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_UPSILON
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_UPSILON: u32 = 0x03a5;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_PHI
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_PHI: u32 = 0x03a6;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_CHI
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_CHI: u32 = 0x03a7;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_PSI
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_PSI: u32 = 0x03a8;
/// 全角 JIS 記号 GREEK_CAPITAL_LETTER_OMEGA
pub const WIDE_JIS_SYMBOL_GREEK_CAPITAL_LETTER_OMEGA: u32 = 0x03a9;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_ALPHA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_ALPHA: u32 = 0x03b1;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_BETA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_BETA: u32 = 0x03b2;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_GAMMA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_GAMMA: u32 = 0x03b3;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_DELTA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_DELTA: u32 = 0x03b4;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_EPSILON
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_EPSILON: u32 = 0x03b5;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_ZETA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_ZETA: u32 = 0x03b6;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_ETA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_ETA: u32 = 0x03b7;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_THETA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_THETA: u32 = 0x03b8;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_IOTA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_IOTA: u32 = 0x03b9;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_KAPPA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_KAPPA: u32 = 0x03ba;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_LAMDA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_LAMDA: u32 = 0x03bb;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_MU
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_MU: u32 = 0x03bc;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_NU
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_NU: u32 = 0x03bd;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_XI
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_XI: u32 = 0x03be;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_OMICRON
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_OMICRON: u32 = 0x03bf;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_PI
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_PI: u32 = 0x03c0;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_RHO
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_RHO: u32 = 0x03c1;
/// 半角 JIS 記号 GREEK_SMALL_LETTER_FINAL_SIGMA
pub const NARROW_JIS_SYMBOL_GREEK_SMALL_LETTER_FINAL_SIGMA: u32 = 0x03c2;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_SIGMA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_SIGMA: u32 = 0x03c3;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_TAU
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_TAU: u32 = 0x03c4;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_UPSILON
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_UPSILON: u32 = 0x03c5;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_PHI
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_PHI: u32 = 0x03c6;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_CHI
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_CHI: u32 = 0x03c7;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_PSI
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_PSI: u32 = 0x03c8;
/// 全角 JIS 記号 GREEK_SMALL_LETTER_OMEGA
pub const WIDE_JIS_SYMBOL_GREEK_SMALL_LETTER_OMEGA: u32 = 0x03c9;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_IO
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_IO: u32 = 0x0401;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_A
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_A: u32 = 0x0410;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_BE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_BE: u32 = 0x0411;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_VE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_VE: u32 = 0x0412;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_GHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_GHE: u32 = 0x0413;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_DE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_DE: u32 = 0x0414;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_IE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_IE: u32 = 0x0415;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_ZHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_ZHE: u32 = 0x0416;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_ZE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_ZE: u32 = 0x0417;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_I
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_I: u32 = 0x0418;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_SHORT_I
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_SHORT_I: u32 = 0x0419;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_KA
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_KA: u32 = 0x041a;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_EL
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_EL: u32 = 0x041b;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_EM
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_EM: u32 = 0x041c;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_EN
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_EN: u32 = 0x041d;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_O
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_O: u32 = 0x041e;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_PE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_PE: u32 = 0x041f;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_ER
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_ER: u32 = 0x0420;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_ES
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_ES: u32 = 0x0421;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_TE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_TE: u32 = 0x0422;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_U
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_U: u32 = 0x0423;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_EF
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_EF: u32 = 0x0424;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_HA
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_HA: u32 = 0x0425;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_TSE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_TSE: u32 = 0x0426;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_CHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_CHE: u32 = 0x0427;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_SHA
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_SHA: u32 = 0x0428;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_SHCHA
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_SHCHA: u32 = 0x0429;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_HARD_SIGN
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_HARD_SIGN: u32 = 0x042a;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_YERU
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_YERU: u32 = 0x042b;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_SOFT_SIGN
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_SOFT_SIGN: u32 = 0x042c;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_E
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_E: u32 = 0x042d;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_YU
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_YU: u32 = 0x042e;
/// 全角 JIS 記号 CYRILLIC_CAPITAL_LETTER_YA
pub const WIDE_JIS_SYMBOL_CYRILLIC_CAPITAL_LETTER_YA: u32 = 0x042f;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_A
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_A: u32 = 0x0430;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_BE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_BE: u32 = 0x0431;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_VE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_VE: u32 = 0x0432;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_GHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_GHE: u32 = 0x0433;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_DE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_DE: u32 = 0x0434;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_IE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_IE: u32 = 0x0435;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_ZHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_ZHE: u32 = 0x0436;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_ZE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_ZE: u32 = 0x0437;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_I
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_I: u32 = 0x0438;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_SHORT_I
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_SHORT_I: u32 = 0x0439;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_KA
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_KA: u32 = 0x043a;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_EL
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_EL: u32 = 0x043b;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_EM
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_EM: u32 = 0x043c;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_EN
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_EN: u32 = 0x043d;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_O
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_O: u32 = 0x043e;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_PE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_PE: u32 = 0x043f;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_ER
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_ER: u32 = 0x0440;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_ES
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_ES: u32 = 0x0441;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_TE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_TE: u32 = 0x0442;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_U
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_U: u32 = 0x0443;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_EF
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_EF: u32 = 0x0444;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_HA
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_HA: u32 = 0x0445;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_TSE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_TSE: u32 = 0x0446;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_CHE
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_CHE: u32 = 0x0447;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_SHA
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_SHA: u32 = 0x0448;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_SHCHA
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_SHCHA: u32 = 0x0449;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_HARD_SIGN
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_HARD_SIGN: u32 = 0x044a;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_YERU
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_YERU: u32 = 0x044b;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_SOFT_SIGN
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_SOFT_SIGN: u32 = 0x044c;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_E
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_E: u32 = 0x044d;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_YU
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_YU: u32 = 0x044e;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_YA
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_YA: u32 = 0x044f;
/// 全角 JIS 記号 CYRILLIC_SMALL_LETTER_IO
pub const WIDE_JIS_SYMBOL_CYRILLIC_SMALL_LETTER_IO: u32 = 0x0451;
/// 半角 JIS 記号 LATIN_CAPITAL_LETTER_M_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_CAPITAL_LETTER_M_WITH_ACUTE: u32 = 0x1e3e;
/// 半角 JIS 記号 LATIN_SMALL_LETTER_M_WITH_ACUTE
pub const NARROW_JIS_SYMBOL_LATIN_SMALL_LETTER_M_WITH_ACUTE: u32 = 0x1e3f;
/// 全角 JIS 記号 HYPHEN
pub const WIDE_JIS_SYMBOL_HYPHEN: u32 = 0x2010;
/// 半角 JIS 記号 EN_DASH
pub const NARROW_JIS_SYMBOL_EN_DASH: u32 = 0x2013;
/// 半角 JIS 記号 EM_DASH
pub const NARROW_JIS_SYMBOL_EM_DASH: u32 = 0x2014;
/// 半角 JIS 記号 DOUBLE_VERTICAL_LINE
pub const NARROW_JIS_SYMBOL_DOUBLE_VERTICAL_LINE: u32 = 0x2016;
/// 全角 JIS 記号 LEFT_SINGLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_LEFT_SINGLE_QUOTATION_MARK: u32 = 0x2018;
/// 全角 JIS 記号 RIGHT_SINGLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_RIGHT_SINGLE_QUOTATION_MARK: u32 = 0x2019;
/// 全角 JIS 記号 LEFT_DOUBLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_LEFT_DOUBLE_QUOTATION_MARK: u32 = 0x201c;
/// 全角 JIS 記号 RIGHT_DOUBLE_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_RIGHT_DOUBLE_QUOTATION_MARK: u32 = 0x201d;
/// 全角 JIS 記号 DAGGER
pub const WIDE_JIS_SYMBOL_DAGGER: u32 = 0x2020;
/// 全角 JIS 記号 DOUBLE_DAGGER
pub const WIDE_JIS_SYMBOL_DOUBLE_DAGGER: u32 = 0x2021;
/// 半角 JIS 記号 BULLET
pub const NARROW_JIS_SYMBOL_BULLET: u32 = 0x2022;
/// 全角 JIS 記号 TWO_DOT_LEADER
pub const WIDE_JIS_SYMBOL_TWO_DOT_LEADER: u32 = 0x2025;
/// 全角 JIS 記号 HORIZONTAL_ELLIPSIS
pub const WIDE_JIS_SYMBOL_HORIZONTAL_ELLIPSIS: u32 = 0x2026;
/// 全角 JIS 記号 PER_MILLE_SIGN
pub const WIDE_JIS_SYMBOL_PER_MILLE_SIGN: u32 = 0x2030;
/// 全角 JIS 記号 PRIME
pub const WIDE_JIS_SYMBOL_PRIME: u32 = 0x2032;
/// 全角 JIS 記号 DOUBLE_PRIME
pub const WIDE_JIS_SYMBOL_DOUBLE_PRIME: u32 = 0x2033;
/// 全角 JIS 記号 REFERENCE_MARK
pub const WIDE_JIS_SYMBOL_REFERENCE_MARK: u32 = 0x203b;
/// 半角 JIS 記号 DOUBLE_EXCLAMATION_MARK
pub const NARROW_JIS_SYMBOL_DOUBLE_EXCLAMATION_MARK: u32 = 0x203c;
/// 半角 JIS 記号 OVERLINE
pub const NARROW_JIS_SYMBOL_OVERLINE: u32 = 0x203e;
/// 半角 JIS 記号 UNDERTIE
pub const NARROW_JIS_SYMBOL_UNDERTIE: u32 = 0x203F;
/// 半角 JIS 記号 ASTERISM
pub const NARROW_JIS_SYMBOL_ASTERISM: u32 = 0x2042;
/// 半角 JIS 記号 DOUBLE_QUESTION_MARK
pub const NARROW_JIS_SYMBOL_DOUBLE_QUESTION_MARK: u32 = 0x2047;
/// 半角 JIS 記号 QUESTION_EXCLAMATION_MARK
pub const NARROW_JIS_SYMBOL_QUESTION_EXCLAMATION_MARK: u32 = 0x2048;
/// 半角 JIS 記号 EXCLAMATION_QUESTION_MARK
pub const NARROW_JIS_SYMBOL_EXCLAMATION_QUESTION_MARK: u32 = 0x2049;
/// 半角 JIS 記号 TWO_ASTERISKS_ALIGNED_VERTICALLY
pub const NARROW_JIS_SYMBOL_TWO_ASTERISKS_ALIGNED_VERTICALLY: u32 = 0x2051;
/// 半角 JIS 記号 WON_SIGN
pub const NARROW_JIS_SYMBOL_WON_SIGN: u32 = 0x20A9;
/// 半角 JIS 記号 EURO_SIGN
pub const NARROW_JIS_SYMBOL_EURO_SIGN: u32 = 0x20ac;
/// 全角 JIS 記号 DEGREE_CELSIUS
pub const WIDE_JIS_SYMBOL_DEGREE_CELSIUS: u32 = 0x2103;
/// 半角 JIS 記号 PLANCK_CONSTANT_OVER_TWO_PI
pub const NARROW_JIS_SYMBOL_PLANCK_CONSTANT_OVER_TWO_PI: u32 = 0x210f;
/// 半角 JIS 記号 SCRIPT_SMALL_L
pub const NARROW_JIS_SYMBOL_SCRIPT_SMALL_L: u32 = 0x2113;
/// 全角 JIS 記号 NUMERO_SIGN
pub const WIDE_JIS_SYMBOL_NUMERO_SIGN: u32 = 0x2116;
/// 全角 JIS 記号 TELEPHONE_SIGN
pub const WIDE_JIS_SYMBOL_TELEPHONE_SIGN: u32 = 0x2121;
/// 半角 JIS 記号 INVERTED_OHM_SIGN
pub const NARROW_JIS_SYMBOL_INVERTED_OHM_SIGN: u32 = 0x2127;
/// 全角 JIS 記号 ANGSTROM_SIGN
pub const WIDE_JIS_SYMBOL_ANGSTROM_SIGN: u32 = 0x212b;
/// 半角 JIS 記号 ALEF_SYMBOL
pub const NARROW_JIS_SYMBOL_ALEF_SYMBOL: u32 = 0x2135;
/// 半角 JIS 記号 VULGAR_FRACTION_ONE_THIRD
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_ONE_THIRD: u32 = 0x2153;
/// 半角 JIS 記号 VULGAR_FRACTION_TWO_THIRDS
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_TWO_THIRDS: u32 = 0x2154;
/// 半角 JIS 記号 VULGAR_FRACTION_ONE_FIFTH
pub const NARROW_JIS_SYMBOL_VULGAR_FRACTION_ONE_FIFTH: u32 = 0x2155;
/// 全角 JIS 記号 ROMAN_NUMERAL_ONE
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_ONE: u32 = 0x2160;
/// 全角 JIS 記号 ROMAN_NUMERAL_TWO
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_TWO: u32 = 0x2161;
/// 全角 JIS 記号 ROMAN_NUMERAL_THREE
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_THREE: u32 = 0x2162;
/// 全角 JIS 記号 ROMAN_NUMERAL_FOUR
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_FOUR: u32 = 0x2163;
/// 全角 JIS 記号 ROMAN_NUMERAL_FIVE
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_FIVE: u32 = 0x2164;
/// 全角 JIS 記号 ROMAN_NUMERAL_SIX
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_SIX: u32 = 0x2165;
/// 全角 JIS 記号 ROMAN_NUMERAL_SEVEN
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_SEVEN: u32 = 0x2166;
/// 全角 JIS 記号 ROMAN_NUMERAL_EIGHT
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_EIGHT: u32 = 0x2167;
/// 全角 JIS 記号 ROMAN_NUMERAL_NINE
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_NINE: u32 = 0x2168;
/// 全角 JIS 記号 ROMAN_NUMERAL_TEN
pub const WIDE_JIS_SYMBOL_ROMAN_NUMERAL_TEN: u32 = 0x2169;
/// 半角 JIS 記号 ROMAN_NUMERAL_ELEVEN
pub const NARROW_JIS_SYMBOL_ROMAN_NUMERAL_ELEVEN: u32 = 0x216a;
/// 半角 JIS 記号 ROMAN_NUMERAL_TWELVE
pub const NARROW_JIS_SYMBOL_ROMAN_NUMERAL_TWELVE: u32 = 0x216b;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_ONE
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_ONE: u32 = 0x2170;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_TWO
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_TWO: u32 = 0x2171;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_THREE
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_THREE: u32 = 0x2172;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_FOUR
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_FOUR: u32 = 0x2173;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_FIVE
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_FIVE: u32 = 0x2174;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_SIX
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_SIX: u32 = 0x2175;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_SEVEN
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_SEVEN: u32 = 0x2176;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_EIGHT
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_EIGHT: u32 = 0x2177;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_NINE
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_NINE: u32 = 0x2178;
/// 全角 JIS 記号 SMALL_ROMAN_NUMERAL_TEN
pub const WIDE_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_TEN: u32 = 0x2179;
/// 半角 JIS 記号 SMALL_ROMAN_NUMERAL_ELEVEN
pub const NARROW_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_ELEVEN: u32 = 0x217a;
/// 半角 JIS 記号 SMALL_ROMAN_NUMERAL_TWELVE
pub const NARROW_JIS_SYMBOL_SMALL_ROMAN_NUMERAL_TWELVE: u32 = 0x217b;
/// 全角 JIS 記号 LEFTWARDS_ARROW
pub const WIDE_JIS_SYMBOL_LEFTWARDS_ARROW: u32 = 0x2190;
/// 全角 JIS 記号 UPWARDS_ARROW
pub const WIDE_JIS_SYMBOL_UPWARDS_ARROW: u32 = 0x2191;
/// 全角 JIS 記号 RIGHTWARDS_ARROW
pub const WIDE_JIS_SYMBOL_RIGHTWARDS_ARROW: u32 = 0x2192;
/// 全角 JIS 記号 DOWNWARDS_ARROW
pub const WIDE_JIS_SYMBOL_DOWNWARDS_ARROW: u32 = 0x2193;
/// 半角 JIS 記号 LEFT_RIGHT_ARROW
pub const NARROW_JIS_SYMBOL_LEFT_RIGHT_ARROW: u32 = 0x2194;
/// 半角 JIS 記号 NORTH_WEST_ARROW
pub const NARROW_JIS_SYMBOL_NORTH_WEST_ARROW: u32 = 0x2196;
/// 半角 JIS 記号 NORTH_EAST_ARROW
pub const NARROW_JIS_SYMBOL_NORTH_EAST_ARROW: u32 = 0x2197;
/// 半角 JIS 記号 SOUTH_EAST_ARROW
pub const NARROW_JIS_SYMBOL_SOUTH_EAST_ARROW: u32 = 0x2198;
/// 半角 JIS 記号 SOUTH_WEST_ARROW
pub const NARROW_JIS_SYMBOL_SOUTH_WEST_ARROW: u32 = 0x2199;
/// 半角 JIS 記号 RIGHTWARDS_ARROW_OVER_LEFTWARDS_ARROW
pub const NARROW_JIS_SYMBOL_RIGHTWARDS_ARROW_OVER_LEFTWARDS_ARROW: u32 = 0x21c4;
/// 全角 JIS 記号 RIGHTWARDS_DOUBLE_ARROW
pub const WIDE_JIS_SYMBOL_RIGHTWARDS_DOUBLE_ARROW: u32 = 0x21d2;
/// 全角 JIS 記号 LEFT_RIGHT_DOUBLE_ARROW
pub const WIDE_JIS_SYMBOL_LEFT_RIGHT_DOUBLE_ARROW: u32 = 0x21d4;
/// 半角 JIS 記号 LEFTWARDS_WHITE_ARROW
pub const NARROW_JIS_SYMBOL_LEFTWARDS_WHITE_ARROW: u32 = 0x21e6;
/// 半角 JIS 記号 UPWARDS_WHITE_ARROW
pub const NARROW_JIS_SYMBOL_UPWARDS_WHITE_ARROW: u32 = 0x21e7;
/// 半角 JIS 記号 RIGHTWARDS_WHITE_ARROW
pub const NARROW_JIS_SYMBOL_RIGHTWARDS_WHITE_ARROW: u32 = 0x21e8;
/// 半角 JIS 記号 DOWNWARDS_WHITE_ARROW
pub const NARROW_JIS_SYMBOL_DOWNWARDS_WHITE_ARROW: u32 = 0x21e9;
/// 全角 JIS 記号 FOR_ALL
pub const WIDE_JIS_SYMBOL_FOR_ALL: u32 = 0x2200;
/// 全角 JIS 記号 PARTIAL_DIFFERENTIAL
pub const WIDE_JIS_SYMBOL_PARTIAL_DIFFERENTIAL: u32 = 0x2202;
/// 全角 JIS 記号 THERE_EXISTS
pub const WIDE_JIS_SYMBOL_THERE_EXISTS: u32 = 0x2203;
/// 半角 JIS 記号 EMPTY_SET
pub const NARROW_JIS_SYMBOL_EMPTY_SET: u32 = 0x2205;
/// 全角 JIS 記号 NABLA
pub const WIDE_JIS_SYMBOL_NABLA: u32 = 0x2207;
/// 全角 JIS 記号 ELEMENT_OF
pub const WIDE_JIS_SYMBOL_ELEMENT_OF: u32 = 0x2208;
/// 半角 JIS 記号 NOT_AN_ELEMENT_OF
pub const NARROW_JIS_SYMBOL_NOT_AN_ELEMENT_OF: u32 = 0x2209;
/// 全角 JIS 記号 CONTAINS_AS_MEMBER
pub const WIDE_JIS_SYMBOL_CONTAINS_AS_MEMBER: u32 = 0x220b;
/// 半角 JIS 記号 MINUS_SIGN
pub const NARROW_JIS_SYMBOL_MINUS_SIGN: u32 = 0x2212;
/// 半角 JIS 記号 MINUS_OR_PLUS_SIGN
pub const NARROW_JIS_SYMBOL_MINUS_OR_PLUS_SIGN: u32 = 0x2213;
/// 全角 JIS 記号 SQUARE_ROOT
pub const WIDE_JIS_SYMBOL_SQUARE_ROOT: u32 = 0x221a;
/// 全角 JIS 記号 PROPORTIONAL_TO
pub const WIDE_JIS_SYMBOL_PROPORTIONAL_TO: u32 = 0x221d;
/// 全角 JIS 記号 INFINITY
pub const WIDE_JIS_SYMBOL_INFINITY: u32 = 0x221e;
/// 全角 JIS 記号 RIGHT_ANGLE
pub const WIDE_JIS_SYMBOL_RIGHT_ANGLE: u32 = 0x221f;
/// 全角 JIS 記号 ANGLE
pub const WIDE_JIS_SYMBOL_ANGLE: u32 = 0x2220;
/// 全角 JIS 記号 PARALLEL_TO
pub const WIDE_JIS_SYMBOL_PARALLEL_TO: u32 = 0x2225;
/// 半角 JIS 記号 NOT_PARALLEL_TO
pub const NARROW_JIS_SYMBOL_NOT_PARALLEL_TO: u32 = 0x2226;
/// 全角 JIS 記号 LOGICAL_AND
pub const WIDE_JIS_SYMBOL_LOGICAL_AND: u32 = 0x2227;
/// 全角 JIS 記号 LOGICAL_OR
pub const WIDE_JIS_SYMBOL_LOGICAL_OR: u32 = 0x2228;
/// 全角 JIS 記号 INTERSECTION
pub const WIDE_JIS_SYMBOL_INTERSECTION: u32 = 0x2229;
/// 全角 JIS 記号 UNION
pub const WIDE_JIS_SYMBOL_UNION: u32 = 0x222a;
/// 全角 JIS 記号 INTEGRAL
pub const WIDE_JIS_SYMBOL_INTEGRAL: u32 = 0x222b;
/// 全角 JIS 記号 DOUBLE_INTEGRAL
pub const WIDE_JIS_SYMBOL_DOUBLE_INTEGRAL: u32 = 0x222c;
/// 全角 JIS 記号 CONTOUR_INTEGRAL
pub const WIDE_JIS_SYMBOL_CONTOUR_INTEGRAL: u32 = 0x222e;
/// 全角 JIS 記号 THEREFORE
pub const WIDE_JIS_SYMBOL_THEREFORE: u32 = 0x2234;
/// 全角 JIS 記号 BECAUSE
pub const WIDE_JIS_SYMBOL_BECAUSE: u32 = 0x2235;
/// 全角 JIS 記号 REVERSED_TILDE
pub const WIDE_JIS_SYMBOL_REVERSED_TILDE: u32 = 0x223d;
/// 半角 JIS 記号 ASYMPTOTICALLY_EQUAL_TO
pub const NARROW_JIS_SYMBOL_ASYMPTOTICALLY_EQUAL_TO: u32 = 0x2243;
/// 半角 JIS 記号 APPROXIMATELY_EQUAL_TO
pub const NARROW_JIS_SYMBOL_APPROXIMATELY_EQUAL_TO: u32 = 0x2245;
/// 半角 JIS 記号 ALMOST_EQUAL_TO
pub const NARROW_JIS_SYMBOL_ALMOST_EQUAL_TO: u32 = 0x2248;
/// 全角 JIS 記号 APPROXIMATELY_EQUAL_TO_OR_THE_IMAGE_OF
pub const WIDE_JIS_SYMBOL_APPROXIMATELY_EQUAL_TO_OR_THE_IMAGE_OF: u32 = 0x2252;
/// 全角 JIS 記号 NOT_EQUAL_TO
pub const WIDE_JIS_SYMBOL_NOT_EQUAL_TO: u32 = 0x2260;
/// 全角 JIS 記号 IDENTICAL_TO
pub const WIDE_JIS_SYMBOL_IDENTICAL_TO: u32 = 0x2261;
/// 半角 JIS 記号 NOT_IDENTICAL_TO
pub const NARROW_JIS_SYMBOL_NOT_IDENTICAL_TO: u32 = 0x2262;
/// 全角 JIS 記号 LESS_THAN_OVER_EQUAL_TO
pub const WIDE_JIS_SYMBOL_LESS_THAN_OVER_EQUAL_TO: u32 = 0x2266;
/// 全角 JIS 記号 GREATER_THAN_OVER_EQUAL_TO
pub const WIDE_JIS_SYMBOL_GREATER_THAN_OVER_EQUAL_TO: u32 = 0x2267;
/// 全角 JIS 記号 MUCH_LESS_THAN
pub const WIDE_JIS_SYMBOL_MUCH_LESS_THAN: u32 = 0x226a;
/// 全角 JIS 記号 MUCH_GREATER_THAN
pub const WIDE_JIS_SYMBOL_MUCH_GREATER_THAN: u32 = 0x226b;
/// 半角 JIS 記号 LESS_THAN_OR_GREATER_THAN
pub const NARROW_JIS_SYMBOL_LESS_THAN_OR_GREATER_THAN: u32 = 0x2276;
/// 半角 JIS 記号 GREATER_THAN_OR_LESS_THAN
pub const NARROW_JIS_SYMBOL_GREATER_THAN_OR_LESS_THAN: u32 = 0x2277;
/// 全角 JIS 記号 SUBSET_OF
pub const WIDE_JIS_SYMBOL_SUBSET_OF: u32 = 0x2282;
/// 全角 JIS 記号 SUPERSET_OF
pub const WIDE_JIS_SYMBOL_SUPERSET_OF: u32 = 0x2283;
/// 半角 JIS 記号 NOT_A_SUBSET_OF
pub const NARROW_JIS_SYMBOL_NOT_A_SUBSET_OF: u32 = 0x2284;
/// 半角 JIS 記号 NOT_A_SUPERSET_OF
pub const NARROW_JIS_SYMBOL_NOT_A_SUPERSET_OF: u32 = 0x2285;
/// 全角 JIS 記号 SUBSET_OF_OR_EQUAL_TO
pub const WIDE_JIS_SYMBOL_SUBSET_OF_OR_EQUAL_TO: u32 = 0x2286;
/// 全角 JIS 記号 SUPERSET_OF_OR_EQUAL_TO
pub const WIDE_JIS_SYMBOL_SUPERSET_OF_OR_EQUAL_TO: u32 = 0x2287;
/// 半角 JIS 記号 SUBSET_OF_WITH_NOT_EQUAL_TO
pub const NARROW_JIS_SYMBOL_SUBSET_OF_WITH_NOT_EQUAL_TO: u32 = 0x228a;
/// 半角 JIS 記号 SUPERSET_OF_WITH_NOT_EQUAL_TO
pub const NARROW_JIS_SYMBOL_SUPERSET_OF_WITH_NOT_EQUAL_TO: u32 = 0x228b;
/// 半角 JIS 記号 CIRCLED_PLUS
pub const NARROW_JIS_SYMBOL_CIRCLED_PLUS: u32 = 0x2295;
/// 半角 JIS 記号 CIRCLED_MINUS
pub const NARROW_JIS_SYMBOL_CIRCLED_MINUS: u32 = 0x2296;
/// 半角 JIS 記号 CIRCLED_TIMES
pub const NARROW_JIS_SYMBOL_CIRCLED_TIMES: u32 = 0x2297;
/// 全角 JIS 記号 UP_TACK
pub const WIDE_JIS_SYMBOL_UP_TACK: u32 = 0x22a5;
/// 全角 JIS 記号 RIGHT_TRIANGLE
pub const WIDE_JIS_SYMBOL_RIGHT_TRIANGLE: u32 = 0x22bf;
/// 半角 JIS 記号 LESS_THAN_EQUAL_TO_OR_GREATER_THAN
pub const NARROW_JIS_SYMBOL_LESS_THAN_EQUAL_TO_OR_GREATER_THAN: u32 = 0x22da;
/// 半角 JIS 記号 GREATER_THAN_EQUAL_TO_OR_LESS_THAN
pub const NARROW_JIS_SYMBOL_GREATER_THAN_EQUAL_TO_OR_LESS_THAN: u32 = 0x22db;
/// 半角 JIS 記号 PROJECTIVE
pub const NARROW_JIS_SYMBOL_PROJECTIVE: u32 = 0x2305;
/// 半角 JIS 記号 PERSPECTIVE
pub const NARROW_JIS_SYMBOL_PERSPECTIVE: u32 = 0x2306;
/// 全角 JIS 記号 ARC
pub const WIDE_JIS_SYMBOL_ARC: u32 = 0x2312;
/// 半角 JIS 記号 PLACE_OF_INTEREST_SIGN
pub const NARROW_JIS_SYMBOL_PLACE_OF_INTEREST_SIGN: u32 = 0x2318;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_TOP_RIGHT
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_TOP_RIGHT: u32 = 0x23be;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_BOTTOM_RIGHT
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_BOTTOM_RIGHT: u32 = 0x23bf;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_WITH_CIRCLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_WITH_CIRCLE: u32 = 0x23c0;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_CIRCLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_CIRCLE: u32 = 0x23c1;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_CIRCLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_CIRCLE: u32 = 0x23c2;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_WITH_TRIANGLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_WITH_TRIANGLE: u32 = 0x23c3;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_TRIANGLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_TRIANGLE: u32 = 0x23c4;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_TRIANGLE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_TRIANGLE: u32 = 0x23c5;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_WAVE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_WAVE: u32 = 0x23c6;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_WAVE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL_WITH_WAVE: u32 = 0x23c7;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_WAVE
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL_WITH_WAVE: u32 = 0x23c8;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_DOWN_AND_HORIZONTAL: u32 = 0x23c9;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_UP_AND_HORIZONTAL: u32 = 0x23ca;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_TOP_LEFT
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_TOP_LEFT: u32 = 0x23cb;
/// 半角 JIS 記号 DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_BOTTOM_LEFT
pub const NARROW_JIS_SYMBOL_DENTISTRY_SYMBOL_LIGHT_VERTICAL_AND_BOTTOM_LEFT: u32 = 0x23cc;
/// 半角 JIS 記号 RETURN_SYMBOL
pub const NARROW_JIS_SYMBOL_RETURN_SYMBOL: u32 = 0x23ce;
/// 半角 JIS 記号 OPEN_BOX
pub const NARROW_JIS_SYMBOL_OPEN_BOX: u32 = 0x2423;
/// 全角 JIS 記号 CIRCLED_DIGIT_ONE
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_ONE: u32 = 0x2460;
/// 全角 JIS 記号 CIRCLED_DIGIT_TWO
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_TWO: u32 = 0x2461;
/// 全角 JIS 記号 CIRCLED_DIGIT_THREE
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_THREE: u32 = 0x2462;
/// 全角 JIS 記号 CIRCLED_DIGIT_FOUR
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_FOUR: u32 = 0x2463;
/// 全角 JIS 記号 CIRCLED_DIGIT_FIVE
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_FIVE: u32 = 0x2464;
/// 全角 JIS 記号 CIRCLED_DIGIT_SIX
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_SIX: u32 = 0x2465;
/// 全角 JIS 記号 CIRCLED_DIGIT_SEVEN
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_SEVEN: u32 = 0x2466;
/// 全角 JIS 記号 CIRCLED_DIGIT_EIGHT
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_EIGHT: u32 = 0x2467;
/// 全角 JIS 記号 CIRCLED_DIGIT_NINE
pub const WIDE_JIS_SYMBOL_CIRCLED_DIGIT_NINE: u32 = 0x2468;
/// 全角 JIS 記号 CIRCLED_NUMBER_TEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_TEN: u32 = 0x2469;
/// 全角 JIS 記号 CIRCLED_NUMBER_ELEVEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_ELEVEN: u32 = 0x246a;
/// 全角 JIS 記号 CIRCLED_NUMBER_TWELVE
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_TWELVE: u32 = 0x246b;
/// 全角 JIS 記号 CIRCLED_NUMBER_THIRTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_THIRTEEN: u32 = 0x246c;
/// 全角 JIS 記号 CIRCLED_NUMBER_FOURTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_FOURTEEN: u32 = 0x246d;
/// 全角 JIS 記号 CIRCLED_NUMBER_FIFTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_FIFTEEN: u32 = 0x246e;
/// 全角 JIS 記号 CIRCLED_NUMBER_SIXTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_SIXTEEN: u32 = 0x246f;
/// 全角 JIS 記号 CIRCLED_NUMBER_SEVENTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_SEVENTEEN: u32 = 0x2470;
/// 全角 JIS 記号 CIRCLED_NUMBER_EIGHTEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_EIGHTEEN: u32 = 0x2471;
/// 全角 JIS 記号 CIRCLED_NUMBER_NINETEEN
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_NINETEEN: u32 = 0x2472;
/// 全角 JIS 記号 CIRCLED_NUMBER_TWENTY
pub const WIDE_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY: u32 = 0x2473;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_A
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_A: u32 = 0x24d0;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_B
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_B: u32 = 0x24d1;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_C
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_C: u32 = 0x24d2;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_D
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_D: u32 = 0x24d3;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_E
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_E: u32 = 0x24d4;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_F
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_F: u32 = 0x24d5;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_G
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_G: u32 = 0x24d6;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_H
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_H: u32 = 0x24d7;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_I
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_I: u32 = 0x24d8;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_J
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_J: u32 = 0x24d9;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_K
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_K: u32 = 0x24da;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_L
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_L: u32 = 0x24db;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_M
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_M: u32 = 0x24dc;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_N
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_N: u32 = 0x24dd;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_O
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_O: u32 = 0x24de;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_P
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_P: u32 = 0x24df;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_Q
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_Q: u32 = 0x24e0;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_R
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_R: u32 = 0x24e1;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_S
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_S: u32 = 0x24e2;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_T
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_T: u32 = 0x24e3;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_U
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_U: u32 = 0x24e4;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_V
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_V: u32 = 0x24e5;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_W
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_W: u32 = 0x24e6;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_X
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_X: u32 = 0x24e7;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_Y
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_Y: u32 = 0x24e8;
/// 半角 JIS 記号 CIRCLED_LATIN_SMALL_LETTER_Z
pub const NARROW_JIS_SYMBOL_CIRCLED_LATIN_SMALL_LETTER_Z: u32 = 0x24e9;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_ELEVEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_ELEVEN: u32 = 0x24eb;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_TWELVE
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_TWELVE: u32 = 0x24ec;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_THIRTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_THIRTEEN: u32 = 0x24ed;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_FOURTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_FOURTEEN: u32 = 0x24ee;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_FIFTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_FIFTEEN: u32 = 0x24ef;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_SIXTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_SIXTEEN: u32 = 0x24f0;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_SEVENTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_SEVENTEEN: u32 = 0x24f1;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_EIGHTEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_EIGHTEEN: u32 = 0x24f2;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_NINETEEN
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_NINETEEN: u32 = 0x24f3;
/// 半角 JIS 記号 NEGATIVE_CIRCLED_NUMBER_TWENTY
pub const NARROW_JIS_SYMBOL_NEGATIVE_CIRCLED_NUMBER_TWENTY: u32 = 0x24f4;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_ONE
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_ONE: u32 = 0x24f5;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_TWO
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_TWO: u32 = 0x24f6;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_THREE
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_THREE: u32 = 0x24f7;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_FOUR
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_FOUR: u32 = 0x24f8;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_FIVE
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_FIVE: u32 = 0x24f9;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_SIX
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_SIX: u32 = 0x24fa;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_SEVEN
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_SEVEN: u32 = 0x24fb;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_EIGHT
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_EIGHT: u32 = 0x24fc;
/// 半角 JIS 記号 DOUBLE_CIRCLED_DIGIT_NINE
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_DIGIT_NINE: u32 = 0x24fd;
/// 半角 JIS 記号 DOUBLE_CIRCLED_NUMBER_TEN
pub const NARROW_JIS_SYMBOL_DOUBLE_CIRCLED_NUMBER_TEN: u32 = 0x24fe;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_HORIZONTAL: u32 = 0x2500;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_HORIZONTAL: u32 = 0x2501;
/// 全角 JIS 記号 FORMS_LIGHT_VERTICAL
pub const WIDE_JIS_SYMBOL_FORMS_LIGHT_VERTICAL: u32 = 0x2502;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_VERTICAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_VERTICAL: u32 = 0x2503;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_DOWN_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_DOWN_AND_RIGHT: u32 = 0x250c;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_DOWN_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_DOWN_AND_RIGHT: u32 = 0x250f;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_DOWN_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_DOWN_AND_LEFT: u32 = 0x2510;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_DOWN_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_DOWN_AND_LEFT: u32 = 0x2513;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_UP_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_UP_AND_RIGHT: u32 = 0x2514;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_UP_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_UP_AND_RIGHT: u32 = 0x2517;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_UP_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_UP_AND_LEFT: u32 = 0x2518;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_UP_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_UP_AND_LEFT: u32 = 0x251b;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_VERTICAL_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_VERTICAL_AND_RIGHT: u32 = 0x251c;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_LIGHT_AND_RIGHT_HEAVY
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_LIGHT_AND_RIGHT_HEAVY: u32 = 0x251d;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_HEAVY_AND_RIGHT_LIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_HEAVY_AND_RIGHT_LIGHT: u32 = 0x2520;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_VERTICAL_AND_RIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_VERTICAL_AND_RIGHT: u32 = 0x2523;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_VERTICAL_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_VERTICAL_AND_LEFT: u32 = 0x2524;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_LIGHT_AND_LEFT_HEAVY
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_LIGHT_AND_LEFT_HEAVY: u32 = 0x2525;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_HEAVY_AND_LEFT_LIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_HEAVY_AND_LEFT_LIGHT: u32 = 0x2528;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_VERTICAL_AND_LEFT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_VERTICAL_AND_LEFT: u32 = 0x252b;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_DOWN_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_DOWN_AND_HORIZONTAL: u32 = 0x252c;
/// 全角 JIS 記号 BOX_DRAWINGS_DOWN_LIGHT_AND_HORIZONTAL_HEAVY
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_DOWN_LIGHT_AND_HORIZONTAL_HEAVY: u32 = 0x252f;
/// 全角 JIS 記号 BOX_DRAWINGS_DOWN_HEAVY_AND_HORIZONTAL_LIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_DOWN_HEAVY_AND_HORIZONTAL_LIGHT: u32 = 0x2530;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_DOWN_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_DOWN_AND_HORIZONTAL: u32 = 0x2533;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_UP_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_UP_AND_HORIZONTAL: u32 = 0x2534;
/// 全角 JIS 記号 BOX_DRAWINGS_UP_LIGHT_AND_HORIZONTAL_HEAVY
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_UP_LIGHT_AND_HORIZONTAL_HEAVY: u32 = 0x2537;
/// 全角 JIS 記号 BOX_DRAWINGS_UP_HEAVY_AND_HORIZONTAL_LIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_UP_HEAVY_AND_HORIZONTAL_LIGHT: u32 = 0x2538;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_UP_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_UP_AND_HORIZONTAL: u32 = 0x253b;
/// 全角 JIS 記号 BOX_DRAWINGS_LIGHT_VERTICAL_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_LIGHT_VERTICAL_AND_HORIZONTAL: u32 = 0x253c;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_LIGHT_AND_HORIZONTAL_HEAVY
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_LIGHT_AND_HORIZONTAL_HEAVY: u32 = 0x253f;
/// 全角 JIS 記号 BOX_DRAWINGS_VERTICAL_HEAVY_AND_HORIZONTAL_LIGHT
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_VERTICAL_HEAVY_AND_HORIZONTAL_LIGHT: u32 = 0x2542;
/// 全角 JIS 記号 BOX_DRAWINGS_HEAVY_VERTICAL_AND_HORIZONTAL
pub const WIDE_JIS_SYMBOL_BOX_DRAWINGS_HEAVY_VERTICAL_AND_HORIZONTAL: u32 = 0x254b;
/// 全角 JIS 記号 BLACK_SQUARE
pub const WIDE_JIS_SYMBOL_BLACK_SQUARE: u32 = 0x25A0;
/// 全角 JIS 記号 WHITE_SQUARE
pub const WIDE_JIS_SYMBOL_WHITE_SQUARE: u32 = 0x25a1;
/// 半角 JIS 記号 WHITE_PARALLELOGRAM
pub const NARROW_JIS_SYMBOL_WHITE_PARALLELOGRAM: u32 = 0x25b1;
/// 全角 JIS 記号 BLACK_UP_POINTING_TRIANGLE
pub const WIDE_JIS_SYMBOL_BLACK_UP_POINTING_TRIANGLE: u32 = 0x25b2;
/// 全角 JIS 記号 WHITE_UP_POINTING_TRIANGLE
pub const WIDE_JIS_SYMBOL_WHITE_UP_POINTING_TRIANGLE: u32 = 0x25b3;
/// 半角 JIS 記号 BLACK_RIGHT_POINTING_TRIANGLE
pub const NARROW_JIS_SYMBOL_BLACK_RIGHT_POINTING_TRIANGLE: u32 = 0x25b6;
/// 半角 JIS 記号 WHITE_RIGHT_POINTING_TRIANGLE
pub const NARROW_JIS_SYMBOL_WHITE_RIGHT_POINTING_TRIANGLE: u32 = 0x25b7;
/// 全角 JIS 記号 BLACK_DOWN_POINTING_TRIANGLE
pub const WIDE_JIS_SYMBOL_BLACK_DOWN_POINTING_TRIANGLE: u32 = 0x25bc;
/// 全角 JIS 記号 WHITE_DOWN_POINTING_TRIANGLE
pub const WIDE_JIS_SYMBOL_WHITE_DOWN_POINTING_TRIANGLE: u32 = 0x25bd;
/// 半角 JIS 記号 BLACK_LEFT_POINTING_TRIANGLE
pub const NARROW_JIS_SYMBOL_BLACK_LEFT_POINTING_TRIANGLE: u32 = 0x25c0;
/// 半角 JIS 記号 WHITE_LEFT_POINTING_TRIANGLE
pub const NARROW_JIS_SYMBOL_WHITE_LEFT_POINTING_TRIANGLE: u32 = 0x25c1;
/// 全角 JIS 記号 BLACK_DIAMOND
pub const WIDE_JIS_SYMBOL_BLACK_DIAMOND: u32 = 0x25c6;
/// 全角 JIS 記号 WHITE_DIAMOND
pub const WIDE_JIS_SYMBOL_WHITE_DIAMOND: u32 = 0x25c7;
/// 半角 JIS 記号 FISHEYE
pub const NARROW_JIS_SYMBOL_FISHEYE: u32 = 0x25c9;
/// 全角 JIS 記号 WHITE_CIRCLE
pub const WIDE_JIS_SYMBOL_WHITE_CIRCLE: u32 = 0x25CB;
/// 全角 JIS 記号 BULLSEYE
pub const WIDE_JIS_SYMBOL_BULLSEYE: u32 = 0x25ce;
/// 全角 JIS 記号 BLACK_CIRCLE
pub const WIDE_JIS_SYMBOL_BLACK_CIRCLE: u32 = 0x25cf;
/// 半角 JIS 記号 CIRCLE_WITH_LEFT_HALF_BLACK
pub const NARROW_JIS_SYMBOL_CIRCLE_WITH_LEFT_HALF_BLACK: u32 = 0x25d0;
/// 半角 JIS 記号 CIRCLE_WITH_RIGHT_HALF_BLACK
pub const NARROW_JIS_SYMBOL_CIRCLE_WITH_RIGHT_HALF_BLACK: u32 = 0x25d1;
/// 半角 JIS 記号 CIRCLE_WITH_LOWER_HALF_BLACK
pub const NARROW_JIS_SYMBOL_CIRCLE_WITH_LOWER_HALF_BLACK: u32 = 0x25d2;
/// 半角 JIS 記号 CIRCLE_WITH_UPPER_HALF_BLACK
pub const NARROW_JIS_SYMBOL_CIRCLE_WITH_UPPER_HALF_BLACK: u32 = 0x25d3;
/// 半角 JIS 記号 WHITE_BULLET
pub const NARROW_JIS_SYMBOL_WHITE_BULLET: u32 = 0x25e6;
/// 全角 JIS 記号 LARGE_CIRCLE
pub const WIDE_JIS_SYMBOL_LARGE_CIRCLE: u32 = 0x25ef;
/// 半角 JIS 記号 BLACK_SUN_WITH_RAYS
pub const NARROW_JIS_SYMBOL_BLACK_SUN_WITH_RAYS: u32 = 0x2600;
/// 半角 JIS 記号 CLOUD
pub const NARROW_JIS_SYMBOL_CLOUD: u32 = 0x2601;
/// 半角 JIS 記号 UMBRELLA
pub const NARROW_JIS_SYMBOL_UMBRELLA: u32 = 0x2602;
/// 半角 JIS 記号 SNOWMAN
pub const NARROW_JIS_SYMBOL_SNOWMAN: u32 = 0x2603;
/// 全角 JIS 記号 BLACK_STAR
pub const WIDE_JIS_SYMBOL_BLACK_STAR: u32 = 0x2605;
/// 全角 JIS 記号 WHITE_STAR
pub const WIDE_JIS_SYMBOL_WHITE_STAR: u32 = 0x2606;
/// 半角 JIS 記号 BLACK_TELEPHONE
pub const NARROW_JIS_SYMBOL_BLACK_TELEPHONE: u32 = 0x260e;
/// 半角 JIS 記号 WHITE_SHOGI_PIECE
pub const NARROW_JIS_SYMBOL_WHITE_SHOGI_PIECE: u32 = 0x2616;
/// 半角 JIS 記号 BLACK_SHOGI_PIECE
pub const NARROW_JIS_SYMBOL_BLACK_SHOGI_PIECE: u32 = 0x2617;
/// 半角 JIS 記号 WHITE_RIGHT_POINTING_INDEX
pub const NARROW_JIS_SYMBOL_WHITE_RIGHT_POINTING_INDEX: u32 = 0x261e;
/// 全角 JIS 記号 FEMALE_SIGN
pub const WIDE_JIS_SYMBOL_FEMALE_SIGN: u32 = 0x2640;
/// 全角 JIS 記号 MALE_SIGN
pub const WIDE_JIS_SYMBOL_MALE_SIGN: u32 = 0x2642;
/// 半角 JIS 記号 BLACK_SPADE_SUIT
pub const NARROW_JIS_SYMBOL_BLACK_SPADE_SUIT: u32 = 0x2660;
/// 半角 JIS 記号 WHITE_HEART_SUIT
pub const NARROW_JIS_SYMBOL_WHITE_HEART_SUIT: u32 = 0x2661;
/// 半角 JIS 記号 WHITE_DIAMOND_SUIT
pub const NARROW_JIS_SYMBOL_WHITE_DIAMOND_SUIT: u32 = 0x2662;
/// 半角 JIS 記号 BLACK_CLUB_SUIT
pub const NARROW_JIS_SYMBOL_BLACK_CLUB_SUIT: u32 = 0x2663;
/// 半角 JIS 記号 WHITE_SPADE_SUIT
pub const NARROW_JIS_SYMBOL_WHITE_SPADE_SUIT: u32 = 0x2664;
/// 半角 JIS 記号 BLACK_HEART_SUIT
pub const NARROW_JIS_SYMBOL_BLACK_HEART_SUIT: u32 = 0x2665;
/// 半角 JIS 記号 BLACK_DIAMOND_SUIT
pub const NARROW_JIS_SYMBOL_BLACK_DIAMOND_SUIT: u32 = 0x2666;
/// 半角 JIS 記号 WHITE_CLUB_SUIT
pub const NARROW_JIS_SYMBOL_WHITE_CLUB_SUIT: u32 = 0x2667;
/// 半角 JIS 記号 HOT_SPRINGS
pub const NARROW_JIS_SYMBOL_HOT_SPRINGS: u32 = 0x2668;
/// 半角 JIS 記号 QUARTER_NOTE
pub const NARROW_JIS_SYMBOL_QUARTER_NOTE: u32 = 0x2669;
/// 全角 JIS 記号 EIGHTH_NOTE
pub const WIDE_JIS_SYMBOL_EIGHTH_NOTE: u32 = 0x266a;
/// 半角 JIS 記号 BEAMED_EIGHTH_NOTES
pub const NARROW_JIS_SYMBOL_BEAMED_EIGHTH_NOTES: u32 = 0x266b;
/// 半角 JIS 記号 BEAMED_SIXTEENTH_NOTES
pub const NARROW_JIS_SYMBOL_BEAMED_SIXTEENTH_NOTES: u32 = 0x266c;
/// 全角 JIS 記号 MUSIC_FLAT_SIGN
pub const WIDE_JIS_SYMBOL_MUSIC_FLAT_SIGN: u32 = 0x266d;
/// 半角 JIS 記号 MUSIC_NATURAL_SIGN
pub const NARROW_JIS_SYMBOL_MUSIC_NATURAL_SIGN: u32 = 0x266e;
/// 全角 JIS 記号 MUSIC_SHARP_SIGN
pub const WIDE_JIS_SYMBOL_MUSIC_SHARP_SIGN: u32 = 0x266f;
/// 半角 JIS 記号 CHECK_MARK
pub const NARROW_JIS_SYMBOL_CHECK_MARK: u32 = 0x2713;
/// 半角 JIS 記号 BLACK_DIAMOND_MINUS_WHITE_X
pub const NARROW_JIS_SYMBOL_BLACK_DIAMOND_MINUS_WHITE_X: u32 = 0x2756;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_ONE
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_ONE: u32 = 0x2776;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_TWO
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_TWO: u32 = 0x2777;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_THREE
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_THREE: u32 = 0x2778;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_FOUR
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_FOUR: u32 = 0x2779;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_FIVE
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_FIVE: u32 = 0x277a;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_SIX
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_SIX: u32 = 0x277b;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_SEVEN
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_SEVEN: u32 = 0x277c;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_EIGHT
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_EIGHT: u32 = 0x277d;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_DIGIT_NINE
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_DIGIT_NINE: u32 = 0x277e;
/// 半角 JIS 記号 DINGBAT_NEGATIVE_CIRCLED_NUMBER_TEN
pub const NARROW_JIS_SYMBOL_DINGBAT_NEGATIVE_CIRCLED_NUMBER_TEN: u32 = 0x277f;
/// 半角 JIS 記号 ARROW_POINTING_RIGHTWARDS_THEN_CURVING_UPWARDS
pub const NARROW_JIS_SYMBOL_ARROW_POINTING_RIGHTWARDS_THEN_CURVING_UPWARDS: u32 = 0x2934;
/// 半角 JIS 記号 ARROW_POINTING_RIGHTWARDS_THEN_CURVING_DOWNWARDS
pub const NARROW_JIS_SYMBOL_ARROW_POINTING_RIGHTWARDS_THEN_CURVING_DOWNWARDS: u32 = 0x2935;
/// 全角 JIS 記号 LEFT_WHITE_PARENTHESIS
pub const WIDE_JIS_SYMBOL_LEFT_WHITE_PARENTHESIS: u32 = 0x2985;
/// 全角 JIS 記号 RIGHT_WHITE_PARENTHESIS
pub const WIDE_JIS_SYMBOL_RIGHT_WHITE_PARENTHESIS: u32 = 0x2986;
/// 半角 JIS 記号 CIRCLED_BULLET
pub const NARROW_JIS_SYMBOL_CIRCLED_BULLET: u32 = 0x29bf;
/// 半角 JIS 記号 DOUBLE_PLUS
pub const NARROW_JIS_SYMBOL_DOUBLE_PLUS: u32 = 0x29fa;
/// 半角 JIS 記号 TRIPLE_PLUS
pub const NARROW_JIS_SYMBOL_TRIPLE_PLUS: u32 = 0x29fb;
/// 全角 ASCII文字 記号 SPACE
pub const WIDE_ASCII_SYMBOL_SPACE: u32 = 0x3000;
/// 全角 JIS 記号 IDEOGRAPHIC_COMMA
pub const WIDE_JIS_SYMBOL_IDEOGRAPHIC_COMMA: u32 = 0x3001;
/// 全角 JIS 記号 IDEOGRAPHIC_FULL_STOP
pub const WIDE_JIS_SYMBOL_IDEOGRAPHIC_FULL_STOP: u32 = 0x3002;
/// 全角 JIS 記号 DITTO_MARK
pub const WIDE_JIS_SYMBOL_DITTO_MARK: u32 = 0x3003;
/// 全角 JIS 記号 IDEOGRAPHIC_ITERATION_MARK
pub const WIDE_JIS_SYMBOL_IDEOGRAPHIC_ITERATION_MARK: u32 = 0x3005;
/// 全角 JIS 記号 IDEOGRAPHIC_CLOSING_MARK
pub const WIDE_JIS_SYMBOL_IDEOGRAPHIC_CLOSING_MARK: u32 = 0x3006;
/// 全角 JIS 記号 IDEOGRAPHIC_NUMBER_ZERO
pub const WIDE_JIS_SYMBOL_IDEOGRAPHIC_NUMBER_ZERO: u32 = 0x3007;
/// 全角 JIS 記号 LEFT_ANGLE_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_ANGLE_BRACKET: u32 = 0x3008;
/// 全角 JIS 記号 RIGHT_ANGLE_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_ANGLE_BRACKET: u32 = 0x3009;
/// 全角 JIS 記号 LEFT_DOUBLE_ANGLE_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_DOUBLE_ANGLE_BRACKET: u32 = 0x300a;
/// 全角 JIS 記号 RIGHT_DOUBLE_ANGLE_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_DOUBLE_ANGLE_BRACKET: u32 = 0x300b;
/// 全角 JIS 記号 LEFT_CORNER_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_CORNER_BRACKET: u32 = 0x300C;
/// 全角 JIS 記号 RIGHT_CORNER_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_CORNER_BRACKET: u32 = 0x300D;
/// 全角 JIS 記号 LEFT_WHITE_CORNER_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_WHITE_CORNER_BRACKET: u32 = 0x300e;
/// 全角 JIS 記号 RIGHT_WHITE_CORNER_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_WHITE_CORNER_BRACKET: u32 = 0x300f;
/// 全角 JIS 記号 LEFT_BLACK_LENTICULAR_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_BLACK_LENTICULAR_BRACKET: u32 = 0x3010;
/// 全角 JIS 記号 RIGHT_BLACK_LENTICULAR_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_BLACK_LENTICULAR_BRACKET: u32 = 0x3011;
/// 全角 JIS 記号 POSTAL_MARK
pub const WIDE_JIS_SYMBOL_POSTAL_MARK: u32 = 0x3012;
/// 全角 JIS 記号 GETA_MARK
pub const WIDE_JIS_SYMBOL_GETA_MARK: u32 = 0x3013;
/// 全角 JIS 記号 LEFT_TORTOISE_SHELL_BRACKET
pub const WIDE_JIS_SYMBOL_LEFT_TORTOISE_SHELL_BRACKET: u32 = 0x3014;
/// 全角 JIS 記号 RIGHT_TORTOISE_SHELL_BRACKET
pub const WIDE_JIS_SYMBOL_RIGHT_TORTOISE_SHELL_BRACKET: u32 = 0x3015;
/// 半角 JIS 記号 LEFT_WHITE_LENTICULAR_BRACKET
pub const NARROW_JIS_SYMBOL_LEFT_WHITE_LENTICULAR_BRACKET: u32 = 0x3016;
/// 半角 JIS 記号 RIGHT_WHITE_LENTICULAR_BRACKET
pub const NARROW_JIS_SYMBOL_RIGHT_WHITE_LENTICULAR_BRACKET: u32 = 0x3017;
/// 半角 JIS 記号 LEFT_WHITE_TORTOISE_SHELL_BRACKET
pub const NARROW_JIS_SYMBOL_LEFT_WHITE_TORTOISE_SHELL_BRACKET: u32 = 0x3018;
/// 半角 JIS 記号 RIGHT_WHITE_TORTOISE_SHELL_BRACKET
pub const NARROW_JIS_SYMBOL_RIGHT_WHITE_TORTOISE_SHELL_BRACKET: u32 = 0x3019;
/// 半角 JIS 記号 WAVE_DASH
pub const NARROW_JIS_SYMBOL_WAVE_DASH: u32 = 0x301c;
/// 全角 JIS 記号 REVERSED_DOUBLE_PRIME_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_REVERSED_DOUBLE_PRIME_QUOTATION_MARK: u32 = 0x301d;
/// 全角 JIS 記号 LOW_DOUBLE_PRIME_QUOTATION_MARK
pub const WIDE_JIS_SYMBOL_LOW_DOUBLE_PRIME_QUOTATION_MARK: u32 = 0x301f;
/// 半角 JIS 記号 POSTAL_MARK_FACE
pub const NARROW_JIS_SYMBOL_POSTAL_MARK_FACE: u32 = 0x3020;
/// 半角 JIS 記号 VERTICAL_KANA_REPEAT_MARK_UPPER_HALF
pub const NARROW_JIS_SYMBOL_VERTICAL_KANA_REPEAT_MARK_UPPER_HALF: u32 = 0x3033;
/// 半角 JIS 記号 VERTICAL_KANA_REPEAT_WITH_VOICED_SOUND_MARK_UPPER_HALF
pub const NARROW_JIS_SYMBOL_VERTICAL_KANA_REPEAT_WITH_VOICED_SOUND_MARK_UPPER_HALF: u32 = 0x3034;
/// 半角 JIS 記号 VERTICAL_KANA_REPEAT_MARK_LOWER_HALF
pub const NARROW_JIS_SYMBOL_VERTICAL_KANA_REPEAT_MARK_LOWER_HALF: u32 = 0x3035;
/// 半角 JIS 記号 VERTICAL_IDEOGRAPHIC_ITERATION_MARK
pub const NARROW_JIS_SYMBOL_VERTICAL_IDEOGRAPHIC_ITERATION_MARK: u32 = 0x303B;
/// 半角 JIS 記号 MASU_MARK
pub const NARROW_JIS_SYMBOL_MASU_MARK: u32 = 0x303C;
/// 半角 JIS 記号 PART_ALTERNATION_MARK
pub const NARROW_JIS_SYMBOL_PART_ALTERNATION_MARK: u32 = 0x303d;
/// 全角 かな文字 ひらがな SMALL_A
pub const WIDE_KANA_HIRAGANA_SMALL_A: u32 = 0x3041;
/// 全角 かな文字 ひらがな A
pub const WIDE_KANA_HIRAGANA_A: u32 = 0x3042;
/// 全角 かな文字 ひらがな SMALL_I
pub const WIDE_KANA_HIRAGANA_SMALL_I: u32 = 0x3043;
/// 全角 かな文字 ひらがな I
pub const WIDE_KANA_HIRAGANA_I: u32 = 0x3044;
/// 全角 かな文字 ひらがな SMALL_U
pub const WIDE_KANA_HIRAGANA_SMALL_U: u32 = 0x3045;
/// 全角 かな文字 ひらがな U
pub const WIDE_KANA_HIRAGANA_U: u32 = 0x3046;
/// 全角 かな文字 ひらがな SMALL_E
pub const WIDE_KANA_HIRAGANA_SMALL_E: u32 = 0x3047;
/// 全角 かな文字 ひらがな E
pub const WIDE_KANA_HIRAGANA_E: u32 = 0x3048;
/// 全角 かな文字 ひらがな SMALL_O
pub const WIDE_KANA_HIRAGANA_SMALL_O: u32 = 0x3049;
/// 全角 かな文字 ひらがな O
pub const WIDE_KANA_HIRAGANA_O: u32 = 0x304A;
/// 全角 かな文字 ひらがな KA
pub const WIDE_KANA_HIRAGANA_KA: u32 = 0x304B;
/// 全角 かな文字 ひらがな GA
pub const WIDE_KANA_HIRAGANA_GA: u32 = 0x304C;
/// 全角 かな文字 ひらがな KI
pub const WIDE_KANA_HIRAGANA_KI: u32 = 0x304D;
/// 全角 かな文字 ひらがな GI
pub const WIDE_KANA_HIRAGANA_GI: u32 = 0x304E;
/// 全角 かな文字 ひらがな KU
pub const WIDE_KANA_HIRAGANA_KU: u32 = 0x304F;
/// 全角 かな文字 ひらがな GU
pub const WIDE_KANA_HIRAGANA_GU: u32 = 0x3050;
/// 全角 かな文字 ひらがな KE
pub const WIDE_KANA_HIRAGANA_KE: u32 = 0x3051;
/// 全角 かな文字 ひらがな GE
pub const WIDE_KANA_HIRAGANA_GE: u32 = 0x3052;
/// 全角 かな文字 ひらがな KO
pub const WIDE_KANA_HIRAGANA_KO: u32 = 0x3053;
/// 全角 かな文字 ひらがな GO
pub const WIDE_KANA_HIRAGANA_GO: u32 = 0x3054;
/// 全角 かな文字 ひらがな SA
pub const WIDE_KANA_HIRAGANA_SA: u32 = 0x3055;
/// 全角 かな文字 ひらがな ZA
pub const WIDE_KANA_HIRAGANA_ZA: u32 = 0x3056;
/// 全角 かな文字 ひらがな SI
pub const WIDE_KANA_HIRAGANA_SI: u32 = 0x3057;
/// 全角 かな文字 ひらがな ZI
pub const WIDE_KANA_HIRAGANA_ZI: u32 = 0x3058;
/// 全角 かな文字 ひらがな SU
pub const WIDE_KANA_HIRAGANA_SU: u32 = 0x3059;
/// 全角 かな文字 ひらがな ZU
pub const WIDE_KANA_HIRAGANA_ZU: u32 = 0x305A;
/// 全角 かな文字 ひらがな SE
pub const WIDE_KANA_HIRAGANA_SE: u32 = 0x305B;
/// 全角 かな文字 ひらがな ZE
pub const WIDE_KANA_HIRAGANA_ZE: u32 = 0x305C;
/// 全角 かな文字 ひらがな SO
pub const WIDE_KANA_HIRAGANA_SO: u32 = 0x305D;
/// 全角 かな文字 ひらがな ZO
pub const WIDE_KANA_HIRAGANA_ZO: u32 = 0x305E;
/// 全角 かな文字 ひらがな TA
pub const WIDE_KANA_HIRAGANA_TA: u32 = 0x305F;
/// 全角 かな文字 ひらがな DA
pub const WIDE_KANA_HIRAGANA_DA: u32 = 0x3060;
/// 全角 かな文字 ひらがな TI
pub const WIDE_KANA_HIRAGANA_TI: u32 = 0x3061;
/// 全角 かな文字 ひらがな DI
pub const WIDE_KANA_HIRAGANA_DI: u32 = 0x3062;
/// 全角 かな文字 ひらがな SMALL_TU
pub const WIDE_KANA_HIRAGANA_SMALL_TU: u32 = 0x3063;
/// 全角 かな文字 ひらがな TU
pub const WIDE_KANA_HIRAGANA_TU: u32 = 0x3064;
/// 全角 かな文字 ひらがな DU
pub const WIDE_KANA_HIRAGANA_DU: u32 = 0x3065;
/// 全角 かな文字 ひらがな TE
pub const WIDE_KANA_HIRAGANA_TE: u32 = 0x3066;
/// 全角 かな文字 ひらがな DE
pub const WIDE_KANA_HIRAGANA_DE: u32 = 0x3067;
/// 全角 かな文字 ひらがな TO
pub const WIDE_KANA_HIRAGANA_TO: u32 = 0x3068;
/// 全角 かな文字 ひらがな DO
pub const WIDE_KANA_HIRAGANA_DO: u32 = 0x3069;
/// 全角 かな文字 ひらがな NA
pub const WIDE_KANA_HIRAGANA_NA: u32 = 0x306A;
/// 全角 かな文字 ひらがな NI
pub const WIDE_KANA_HIRAGANA_NI: u32 = 0x306B;
/// 全角 かな文字 ひらがな NU
pub const WIDE_KANA_HIRAGANA_NU: u32 = 0x306C;
/// 全角 かな文字 ひらがな NE
pub const WIDE_KANA_HIRAGANA_NE: u32 = 0x306D;
/// 全角 かな文字 ひらがな NO
pub const WIDE_KANA_HIRAGANA_NO: u32 = 0x306E;
/// 全角 かな文字 ひらがな HA
pub const WIDE_KANA_HIRAGANA_HA: u32 = 0x306F;
/// 全角 かな文字 ひらがな BA
pub const WIDE_KANA_HIRAGANA_BA: u32 = 0x3070;
/// 全角 かな文字 ひらがな PA
pub const WIDE_KANA_HIRAGANA_PA: u32 = 0x3071;
/// 全角 かな文字 ひらがな HI
pub const WIDE_KANA_HIRAGANA_HI: u32 = 0x3072;
/// 全角 かな文字 ひらがな BI
pub const WIDE_KANA_HIRAGANA_BI: u32 = 0x3073;
/// 全角 かな文字 ひらがな PI
pub const WIDE_KANA_HIRAGANA_PI: u32 = 0x3074;
/// 全角 かな文字 ひらがな HU
pub const WIDE_KANA_HIRAGANA_HU: u32 = 0x3075;
/// 全角 かな文字 ひらがな BU
pub const WIDE_KANA_HIRAGANA_BU: u32 = 0x3076;
/// 全角 かな文字 ひらがな PU
pub const WIDE_KANA_HIRAGANA_PU: u32 = 0x3077;
/// 全角 かな文字 ひらがな HE
pub const WIDE_KANA_HIRAGANA_HE: u32 = 0x3078;
/// 全角 かな文字 ひらがな BE
pub const WIDE_KANA_HIRAGANA_BE: u32 = 0x3079;
/// 全角 かな文字 ひらがな PE
pub const WIDE_KANA_HIRAGANA_PE: u32 = 0x307A;
/// 全角 かな文字 ひらがな HO
pub const WIDE_KANA_HIRAGANA_HO: u32 = 0x307B;
/// 全角 かな文字 ひらがな BO
pub const WIDE_KANA_HIRAGANA_BO: u32 = 0x307C;
/// 全角 かな文字 ひらがな PO
pub const WIDE_KANA_HIRAGANA_PO: u32 = 0x307D;
/// 全角 かな文字 ひらがな MA
pub const WIDE_KANA_HIRAGANA_MA: u32 = 0x307E;
/// 全角 かな文字 ひらがな MI
pub const WIDE_KANA_HIRAGANA_MI: u32 = 0x307F;
/// 全角 かな文字 ひらがな MU
pub const WIDE_KANA_HIRAGANA_MU: u32 = 0x3080;
/// 全角 かな文字 ひらがな ME
pub const WIDE_KANA_HIRAGANA_ME: u32 = 0x3081;
/// 全角 かな文字 ひらがな MO
pub const WIDE_KANA_HIRAGANA_MO: u32 = 0x3082;
/// 全角 かな文字 ひらがな SMALL_YA
pub const WIDE_KANA_HIRAGANA_SMALL_YA: u32 = 0x3083;
/// 全角 かな文字 ひらがな YA
pub const WIDE_KANA_HIRAGANA_YA: u32 = 0x3084;
/// 全角 かな文字 ひらがな SMALL_YU
pub const WIDE_KANA_HIRAGANA_SMALL_YU: u32 = 0x3085;
/// 全角 かな文字 ひらがな YU
pub const WIDE_KANA_HIRAGANA_YU: u32 = 0x3086;
/// 全角 かな文字 ひらがな SMALL_YO
pub const WIDE_KANA_HIRAGANA_SMALL_YO: u32 = 0x3087;
/// 全角 かな文字 ひらがな YO
pub const WIDE_KANA_HIRAGANA_YO: u32 = 0x3088;
/// 全角 かな文字 ひらがな RA
pub const WIDE_KANA_HIRAGANA_RA: u32 = 0x3089;
/// 全角 かな文字 ひらがな RI
pub const WIDE_KANA_HIRAGANA_RI: u32 = 0x308A;
/// 全角 かな文字 ひらがな RU
pub const WIDE_KANA_HIRAGANA_RU: u32 = 0x308B;
/// 全角 かな文字 ひらがな RE
pub const WIDE_KANA_HIRAGANA_RE: u32 = 0x308C;
/// 全角 かな文字 ひらがな RO
pub const WIDE_KANA_HIRAGANA_RO: u32 = 0x308D;
/// 全角 かな文字 ひらがな SMALL_WA
pub const WIDE_KANA_HIRAGANA_SMALL_WA: u32 = 0x308E;
/// 全角 かな文字 ひらがな WA
pub const WIDE_KANA_HIRAGANA_WA: u32 = 0x308F;
/// 全角 かな文字 ひらがな WI
pub const WIDE_KANA_HIRAGANA_WI: u32 = 0x3090;
/// 全角 かな文字 ひらがな WE
pub const WIDE_KANA_HIRAGANA_WE: u32 = 0x3091;
/// 全角 かな文字 ひらがな WO
pub const WIDE_KANA_HIRAGANA_WO: u32 = 0x3092;
/// 全角 かな文字 ひらがな N
pub const WIDE_KANA_HIRAGANA_N: u32 = 0x3093;
/// 全角 かな文字 ひらがな VU
pub const WIDE_KANA_HIRAGANA_VU: u32 = 0x3094;
/// 全角 かな文字 ひらがな SMALL_KA
pub const WIDE_KANA_HIRAGANA_SMALL_KA: u32 = 0x3095;
/// 全角 かな文字 ひらがな SMALL_KE
pub const WIDE_KANA_HIRAGANA_SMALL_KE: u32 = 0x3096;
/// 全角 JIS 記号 KATAKANA_VOICED_SOUND_MARK
pub const WIDE_JIS_SYMBOL_KATAKANA_VOICED_SOUND_MARK: u32 = 0x3099;
/// 全角 JIS 記号 KATAKANA_SEMI-VOICED_SOUND_MARK
pub const WIDE_JIS_SYMBOL_KATAKANA_SEMI_VOICED_SOUND_MARK: u32 = 0x309A;
/// 全角 JIS 記号 KATAKANA_HIRAGANA_VOICED_SOUND_MARK
pub const WIDE_JIS_SYMBOL_KATAKANA_HIRAGANA_VOICED_SOUND_MARK: u32 = 0x309b;
/// 全角 JIS 記号 KATAKANA_HIRAGANA_SEMI_VOICED_SOUND_MARK
pub const WIDE_JIS_SYMBOL_KATAKANA_HIRAGANA_SEMI_VOICED_SOUND_MARK: u32 = 0x309c;
/// 全角 かな文字 ひらがな ITERATION_MARK
pub const WIDE_KANA_HIRAGANA_ITERATION_MARK: u32 = 0x309D;
/// 全角 かな文字 ひらがな VOICED_ITERATION_MARK
pub const WIDE_KANA_HIRAGANA_VOICED_ITERATION_MARK: u32 = 0x309E;
/// 全角 かな文字 ひらがな DIGRAPH_YORI
pub const WIDE_KANA_HIRAGANA_DIGRAPH_YORI: u32 = 0x309F;
/// 半角 JIS 記号 KATAKANA_HIRAGANA_DOUBLE_HYPHEN
pub const NARROW_JIS_SYMBOL_KATAKANA_HIRAGANA_DOUBLE_HYPHEN: u32 = 0x30a0;
/// 全角 かな文字 カタカナ SMALL_A
pub const WIDE_KANA_KATAKANA_SMALL_A: u32 = 0x30A1;
/// 全角 かな文字 カタカナ A
pub const WIDE_KANA_KATAKANA_A: u32 = 0x30A2;
/// 全角 かな文字 カタカナ SMALL_I
pub const WIDE_KANA_KATAKANA_SMALL_I: u32 = 0x30A3;
/// 全角 かな文字 カタカナ I
pub const WIDE_KANA_KATAKANA_I: u32 = 0x30A4;
/// 全角 かな文字 カタカナ SMALL_U
pub const WIDE_KANA_KATAKANA_SMALL_U: u32 = 0x30A5;
/// 全角 かな文字 カタカナ U
pub const WIDE_KANA_KATAKANA_U: u32 = 0x30A6;
/// 全角 かな文字 カタカナ SMALL_E
pub const WIDE_KANA_KATAKANA_SMALL_E: u32 = 0x30A7;
/// 全角 かな文字 カタカナ E
pub const WIDE_KANA_KATAKANA_E: u32 = 0x30A8;
/// 全角 かな文字 カタカナ SMALL_O
pub const WIDE_KANA_KATAKANA_SMALL_O: u32 = 0x30A9;
/// 全角 かな文字 カタカナ O
pub const WIDE_KANA_KATAKANA_O: u32 = 0x30AA;
/// 全角 かな文字 カタカナ KA
pub const WIDE_KANA_KATAKANA_KA: u32 = 0x30AB;
/// 全角 かな文字 カタカナ GA
pub const WIDE_KANA_KATAKANA_GA: u32 = 0x30AC;
/// 全角 かな文字 カタカナ KI
pub const WIDE_KANA_KATAKANA_KI: u32 = 0x30AD;
/// 全角 かな文字 カタカナ GI
pub const WIDE_KANA_KATAKANA_GI: u32 = 0x30AE;
/// 全角 かな文字 カタカナ KU
pub const WIDE_KANA_KATAKANA_KU: u32 = 0x30AF;
/// 全角 かな文字 カタカナ GU
pub const WIDE_KANA_KATAKANA_GU: u32 = 0x30B0;
/// 全角 かな文字 カタカナ KE
pub const WIDE_KANA_KATAKANA_KE: u32 = 0x30B1;
/// 全角 かな文字 カタカナ GE
pub const WIDE_KANA_KATAKANA_GE: u32 = 0x30B2;
/// 全角 かな文字 カタカナ KO
pub const WIDE_KANA_KATAKANA_KO: u32 = 0x30B3;
/// 全角 かな文字 カタカナ GO
pub const WIDE_KANA_KATAKANA_GO: u32 = 0x30B4;
/// 全角 かな文字 カタカナ SA
pub const WIDE_KANA_KATAKANA_SA: u32 = 0x30B5;
/// 全角 かな文字 カタカナ ZA
pub const WIDE_KANA_KATAKANA_ZA: u32 = 0x30B6;
/// 全角 かな文字 カタカナ SI
pub const WIDE_KANA_KATAKANA_SI: u32 = 0x30B7;
/// 全角 かな文字 カタカナ ZI
pub const WIDE_KANA_KATAKANA_ZI: u32 = 0x30B8;
/// 全角 かな文字 カタカナ SU
pub const WIDE_KANA_KATAKANA_SU: u32 = 0x30B9;
/// 全角 かな文字 カタカナ ZU
pub const WIDE_KANA_KATAKANA_ZU: u32 = 0x30BA;
/// 全角 かな文字 カタカナ SE
pub const WIDE_KANA_KATAKANA_SE: u32 = 0x30BB;
/// 全角 かな文字 カタカナ ZE
pub const WIDE_KANA_KATAKANA_ZE: u32 = 0x30BC;
/// 全角 かな文字 カタカナ SO
pub const WIDE_KANA_KATAKANA_SO: u32 = 0x30BD;
/// 全角 かな文字 カタカナ ZO
pub const WIDE_KANA_KATAKANA_ZO: u32 = 0x30BE;
/// 全角 かな文字 カタカナ TA
pub const WIDE_KANA_KATAKANA_TA: u32 = 0x30BF;
/// 全角 かな文字 カタカナ DA
pub const WIDE_KANA_KATAKANA_DA: u32 = 0x30C0;
/// 全角 かな文字 カタカナ TI
pub const WIDE_KANA_KATAKANA_TI: u32 = 0x30C1;
/// 全角 かな文字 カタカナ DI
pub const WIDE_KANA_KATAKANA_DI: u32 = 0x30C2;
/// 全角 かな文字 カタカナ SMALL_TU
pub const WIDE_KANA_KATAKANA_SMALL_TU: u32 = 0x30C3;
/// 全角 かな文字 カタカナ TU
pub const WIDE_KANA_KATAKANA_TU: u32 = 0x30C4;
/// 全角 かな文字 カタカナ DU
pub const WIDE_KANA_KATAKANA_DU: u32 = 0x30C5;
/// 全角 かな文字 カタカナ TE
pub const WIDE_KANA_KATAKANA_TE: u32 = 0x30C6;
/// 全角 かな文字 カタカナ DE
pub const WIDE_KANA_KATAKANA_DE: u32 = 0x30C7;
/// 全角 かな文字 カタカナ TO
pub const WIDE_KANA_KATAKANA_TO: u32 = 0x30C8;
/// 全角 かな文字 カタカナ DO
pub const WIDE_KANA_KATAKANA_DO: u32 = 0x30C9;
/// 全角 かな文字 カタカナ NA
pub const WIDE_KANA_KATAKANA_NA: u32 = 0x30CA;
/// 全角 かな文字 カタカナ NI
pub const WIDE_KANA_KATAKANA_NI: u32 = 0x30CB;
/// 全角 かな文字 カタカナ NU
pub const WIDE_KANA_KATAKANA_NU: u32 = 0x30CC;
/// 全角 かな文字 カタカナ NE
pub const WIDE_KANA_KATAKANA_NE: u32 = 0x30CD;
/// 全角 かな文字 カタカナ NO
pub const WIDE_KANA_KATAKANA_NO: u32 = 0x30CE;
/// 全角 かな文字 カタカナ HA
pub const WIDE_KANA_KATAKANA_HA: u32 = 0x30CF;
/// 全角 かな文字 カタカナ BA
pub const WIDE_KANA_KATAKANA_BA: u32 = 0x30D0;
/// 全角 かな文字 カタカナ PA
pub const WIDE_KANA_KATAKANA_PA: u32 = 0x30D1;
/// 全角 かな文字 カタカナ HI
pub const WIDE_KANA_KATAKANA_HI: u32 = 0x30D2;
/// 全角 かな文字 カタカナ BI
pub const WIDE_KANA_KATAKANA_BI: u32 = 0x30D3;
/// 全角 かな文字 カタカナ PI
pub const WIDE_KANA_KATAKANA_PI: u32 = 0x30D4;
/// 全角 かな文字 カタカナ HU
pub const WIDE_KANA_KATAKANA_HU: u32 = 0x30D5;
/// 全角 かな文字 カタカナ BU
pub const WIDE_KANA_KATAKANA_BU: u32 = 0x30D6;
/// 全角 かな文字 カタカナ PU
pub const WIDE_KANA_KATAKANA_PU: u32 = 0x30D7;
/// 全角 かな文字 カタカナ HE
pub const WIDE_KANA_KATAKANA_HE: u32 = 0x30D8;
/// 全角 かな文字 カタカナ BE
pub const WIDE_KANA_KATAKANA_BE: u32 = 0x30D9;
/// 全角 かな文字 カタカナ PE
pub const WIDE_KANA_KATAKANA_PE: u32 = 0x30DA;
/// 全角 かな文字 カタカナ HO
pub const WIDE_KANA_KATAKANA_HO: u32 = 0x30DB;
/// 全角 かな文字 カタカナ BO
pub const WIDE_KANA_KATAKANA_BO: u32 = 0x30DC;
/// 全角 かな文字 カタカナ PO
pub const WIDE_KANA_KATAKANA_PO: u32 = 0x30DD;
/// 全角 かな文字 カタカナ MA
pub const WIDE_KANA_KATAKANA_MA: u32 = 0x30DE;
/// 全角 かな文字 カタカナ MI
pub const WIDE_KANA_KATAKANA_MI: u32 = 0x30DF;
/// 全角 かな文字 カタカナ MU
pub const WIDE_KANA_KATAKANA_MU: u32 = 0x30E0;
/// 全角 かな文字 カタカナ ME
pub const WIDE_KANA_KATAKANA_ME: u32 = 0x30E1;
/// 全角 かな文字 カタカナ MO
pub const WIDE_KANA_KATAKANA_MO: u32 = 0x30E2;
/// 全角 かな文字 カタカナ SMALL_YA
pub const WIDE_KANA_KATAKANA_SMALL_YA: u32 = 0x30E3;
/// 全角 かな文字 カタカナ YA
pub const WIDE_KANA_KATAKANA_YA: u32 = 0x30E4;
/// 全角 かな文字 カタカナ SMALL_YU
pub const WIDE_KANA_KATAKANA_SMALL_YU: u32 = 0x30E5;
/// 全角 かな文字 カタカナ YU
pub const WIDE_KANA_KATAKANA_YU: u32 = 0x30E6;
/// 全角 かな文字 カタカナ SMALL_YO
pub const WIDE_KANA_KATAKANA_SMALL_YO: u32 = 0x30E7;
/// 全角 かな文字 カタカナ YO
pub const WIDE_KANA_KATAKANA_YO: u32 = 0x30E8;
/// 全角 かな文字 カタカナ RA
pub const WIDE_KANA_KATAKANA_RA: u32 = 0x30E9;
/// 全角 かな文字 カタカナ RI
pub const WIDE_KANA_KATAKANA_RI: u32 = 0x30EA;
/// 全角 かな文字 カタカナ RU
pub const WIDE_KANA_KATAKANA_RU: u32 = 0x30EB;
/// 全角 かな文字 カタカナ RE
pub const WIDE_KANA_KATAKANA_RE: u32 = 0x30EC;
/// 全角 かな文字 カタカナ RO
pub const WIDE_KANA_KATAKANA_RO: u32 = 0x30ED;
/// 全角 かな文字 カタカナ SMALL_WA
pub const WIDE_KANA_KATAKANA_SMALL_WA: u32 = 0x30EE;
/// 全角 かな文字 カタカナ WA
pub const WIDE_KANA_KATAKANA_WA: u32 = 0x30EF;
/// 全角 かな文字 カタカナ WI
pub const WIDE_KANA_KATAKANA_WI: u32 = 0x30F0;
/// 全角 かな文字 カタカナ WE
pub const WIDE_KANA_KATAKANA_WE: u32 = 0x30F1;
/// 全角 かな文字 カタカナ WO
pub const WIDE_KANA_KATAKANA_WO: u32 = 0x30F2;
/// 全角 かな文字 カタカナ N
pub const WIDE_KANA_KATAKANA_N: u32 = 0x30F3;
/// 全角 かな文字 カタカナ VU
pub const WIDE_KANA_KATAKANA_VU: u32 = 0x30F4;
/// 全角 かな文字 カタカナ SMALL_KA
pub const WIDE_KANA_KATAKANA_SMALL_KA: u32 = 0x30F5;
/// 全角 かな文字 カタカナ SMALL_KE
pub const WIDE_KANA_KATAKANA_SMALL_KE: u32 = 0x30F6;
/// 全角 かな文字 カタカナ VA
pub const WIDE_KANA_KATAKANA_VA: u32 = 0x30F7;
/// 全角 かな文字 カタカナ VI
pub const WIDE_KANA_KATAKANA_VI: u32 = 0x30F8;
/// 全角 かな文字 カタカナ VE
pub const WIDE_KANA_KATAKANA_VE: u32 = 0x30F9;
/// 全角 かな文字 カタカナ VO
pub const WIDE_KANA_KATAKANA_VO: u32 = 0x30FA;
/// 全角 JIS 記号 KATAKANA_MIDDLE_DOT
pub const WIDE_JIS_SYMBOL_KATAKANA_MIDDLE_DOT: u32 = 0x30FB;
/// 全角 JIS 記号 PROLONGED_SOUND_MARK
pub const WIDE_JIS_SYMBOL_PROLONGED_SOUND_MARK: u32 = 0x30FC;
/// 全角 かな文字 カタカナ ITERATION_MARK
pub const WIDE_KANA_KATAKANA_ITERATION_MARK: u32 = 0x30FD;
/// 全角 かな文字 カタカナ VOICED_ITERATION_MARK
pub const WIDE_KANA_KATAKANA_VOICED_ITERATION_MARK: u32 = 0x30FE;
/// 全角 かな文字 カタカナ DIGRAPH_YORI
pub const WIDE_KANA_KATAKANA_DIGRAPH_YORI: u32 = 0x30FF;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_KU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_KU: u32 = 0x31f0;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_SI
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_SI: u32 = 0x31f1;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_SU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_SU: u32 = 0x31f2;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_TO
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_TO: u32 = 0x31f3;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_NU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_NU: u32 = 0x31f4;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_HA
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_HA: u32 = 0x31f5;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_HI
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_HI: u32 = 0x31f6;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_HU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_HU: u32 = 0x31f7;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_HE
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_HE: u32 = 0x31f8;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_HO
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_HO: u32 = 0x31f9;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_MU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_MU: u32 = 0x31fa;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_RA
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_RA: u32 = 0x31fb;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_RI
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_RI: u32 = 0x31fc;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_RU
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_RU: u32 = 0x31fd;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_RE
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_RE: u32 = 0x31fe;
/// 半角 JIS 記号 KATAKANA_LETTER_SMALL_RO
pub const NARROW_JIS_SYMBOL_KATAKANA_LETTER_SMALL_RO: u32 = 0x31ff;
/// 全角 JIS 記号 PARENTHESIZED_IDEOGRAPH_STOCK
pub const WIDE_JIS_SYMBOL_PARENTHESIZED_IDEOGRAPH_STOCK: u32 = 0x3231;
/// 全角 JIS 記号 PARENTHESIZED_IDEOGRAPH_HAVE
pub const WIDE_JIS_SYMBOL_PARENTHESIZED_IDEOGRAPH_HAVE: u32 = 0x3232;
/// 全角 JIS 記号 PARENTHESIZED_IDEOGRAPH_REPRESENT
pub const WIDE_JIS_SYMBOL_PARENTHESIZED_IDEOGRAPH_REPRESENT: u32 = 0x3239;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_ONE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_ONE: u32 = 0x3251;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_TWO
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_TWO: u32 = 0x3252;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_THREE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_THREE: u32 = 0x3253;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_FOUR
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_FOUR: u32 = 0x3254;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_FIVE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_FIVE: u32 = 0x3255;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_SIX
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_SIX: u32 = 0x3256;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_SEVEN
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_SEVEN: u32 = 0x3257;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_EIGHT
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_EIGHT: u32 = 0x3258;
/// 半角 JIS 記号 CIRCLED_NUMBER_TWENTY_NINE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_TWENTY_NINE: u32 = 0x3259;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY: u32 = 0x325a;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_ONE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_ONE: u32 = 0x325b;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_TWO
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_TWO: u32 = 0x325c;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_THREE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_THREE: u32 = 0x325d;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_FOUR
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_FOUR: u32 = 0x325e;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_FIVE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_FIVE: u32 = 0x325f;
/// 全角 JIS 記号 CIRCLED_IDEOGRAPH_HIGH
pub const WIDE_JIS_SYMBOL_CIRCLED_IDEOGRAPH_HIGH: u32 = 0x32a4;
/// 全角 JIS 記号 CIRCLED_IDEOGRAPH_CENTRE
pub const WIDE_JIS_SYMBOL_CIRCLED_IDEOGRAPH_CENTRE: u32 = 0x32a5;
/// 全角 JIS 記号 CIRCLED_IDEOGRAPH_LOW
pub const WIDE_JIS_SYMBOL_CIRCLED_IDEOGRAPH_LOW: u32 = 0x32a6;
/// 全角 JIS 記号 CIRCLED_IDEOGRAPH_LEFT
pub const WIDE_JIS_SYMBOL_CIRCLED_IDEOGRAPH_LEFT: u32 = 0x32a7;
/// 全角 JIS 記号 CIRCLED_IDEOGRAPH_RIGHT
pub const WIDE_JIS_SYMBOL_CIRCLED_IDEOGRAPH_RIGHT: u32 = 0x32a8;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_SIX
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_SIX: u32 = 0x32b1;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_SEVEN
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_SEVEN: u32 = 0x32b2;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_EIGHT
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_EIGHT: u32 = 0x32b3;
/// 半角 JIS 記号 CIRCLED_NUMBER_THIRTY_NINE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_THIRTY_NINE: u32 = 0x32b4;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY: u32 = 0x32b5;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_ONE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_ONE: u32 = 0x32b6;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_TWO
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_TWO: u32 = 0x32b7;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_THREE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_THREE: u32 = 0x32b8;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_FOUR
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_FOUR: u32 = 0x32b9;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_FIVE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_FIVE: u32 = 0x32ba;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_SIX
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_SIX: u32 = 0x32bb;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_SEVEN
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_SEVEN: u32 = 0x32bc;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_EIGHT
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_EIGHT: u32 = 0x32bd;
/// 半角 JIS 記号 CIRCLED_NUMBER_FORTY_NINE
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FORTY_NINE: u32 = 0x32be;
/// 半角 JIS 記号 CIRCLED_NUMBER_FIFTY
pub const NARROW_JIS_SYMBOL_CIRCLED_NUMBER_FIFTY: u32 = 0x32bf;
/// 半角 JIS 記号 CIRCLED_KATAKANA_A
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_A: u32 = 0x32d0;
/// 半角 JIS 記号 CIRCLED_KATAKANA_I
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_I: u32 = 0x32d1;
/// 半角 JIS 記号 CIRCLED_KATAKANA_U
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_U: u32 = 0x32d2;
/// 半角 JIS 記号 CIRCLED_KATAKANA_E
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_E: u32 = 0x32d3;
/// 半角 JIS 記号 CIRCLED_KATAKANA_O
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_O: u32 = 0x32d4;
/// 半角 JIS 記号 CIRCLED_KATAKANA_KA
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_KA: u32 = 0x32d5;
/// 半角 JIS 記号 CIRCLED_KATAKANA_KI
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_KI: u32 = 0x32d6;
/// 半角 JIS 記号 CIRCLED_KATAKANA_KU
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_KU: u32 = 0x32d7;
/// 半角 JIS 記号 CIRCLED_KATAKANA_KE
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_KE: u32 = 0x32d8;
/// 半角 JIS 記号 CIRCLED_KATAKANA_KO
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_KO: u32 = 0x32d9;
/// 半角 JIS 記号 CIRCLED_KATAKANA_SA
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_SA: u32 = 0x32da;
/// 半角 JIS 記号 CIRCLED_KATAKANA_SI
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_SI: u32 = 0x32db;
/// 半角 JIS 記号 CIRCLED_KATAKANA_SU
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_SU: u32 = 0x32dc;
/// 半角 JIS 記号 CIRCLED_KATAKANA_SE
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_SE: u32 = 0x32dd;
/// 半角 JIS 記号 CIRCLED_KATAKANA_SO
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_SO: u32 = 0x32de;
/// 半角 JIS 記号 CIRCLED_KATAKANA_TA
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_TA: u32 = 0x32df;
/// 半角 JIS 記号 CIRCLED_KATAKANA_TI
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_TI: u32 = 0x32e0;
/// 半角 JIS 記号 CIRCLED_KATAKANA_TU
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_TU: u32 = 0x32e1;
/// 半角 JIS 記号 CIRCLED_KATAKANA_TE
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_TE: u32 = 0x32e2;
/// 半角 JIS 記号 CIRCLED_KATAKANA_TO
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_TO: u32 = 0x32e3;
/// 半角 JIS 記号 CIRCLED_KATAKANA_NI
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_NI: u32 = 0x32e5;
/// 半角 JIS 記号 CIRCLED_KATAKANA_HA
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_HA: u32 = 0x32e9;
/// 半角 JIS 記号 CIRCLED_KATAKANA_HE
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_HE: u32 = 0x32ec;
/// 半角 JIS 記号 CIRCLED_KATAKANA_HO
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_HO: u32 = 0x32ed;
/// 半角 JIS 記号 CIRCLED_KATAKANA_RO
pub const NARROW_JIS_SYMBOL_CIRCLED_KATAKANA_RO: u32 = 0x32fa;
/// 全角 JIS 記号 SQUARE_AARU
pub const WIDE_JIS_SYMBOL_SQUARE_AARU: u32 = 0x3303;
/// 全角 JIS 記号 SQUARE_KARORII
pub const WIDE_JIS_SYMBOL_SQUARE_KARORII: u32 = 0x330d;
/// 全角 JIS 記号 SQUARE_KIRO
pub const WIDE_JIS_SYMBOL_SQUARE_KIRO: u32 = 0x3314;
/// 全角 JIS 記号 SQUARE_GURAMU
pub const WIDE_JIS_SYMBOL_SQUARE_GURAMU: u32 = 0x3318;
/// 全角 JIS 記号 SQUARE_SENTI
pub const WIDE_JIS_SYMBOL_SQUARE_SENTI: u32 = 0x3322;
/// 全角 JIS 記号 SQUARE_SENTO
pub const WIDE_JIS_SYMBOL_SQUARE_SENTO: u32 = 0x3323;
/// 全角 JIS 記号 SQUARE_DORU
pub const WIDE_JIS_SYMBOL_SQUARE_DORU: u32 = 0x3326;
/// 全角 JIS 記号 SQUARE_TON
pub const WIDE_JIS_SYMBOL_SQUARE_TON: u32 = 0x3327;
/// 全角 JIS 記号 SQUARE_PAASENTO
pub const WIDE_JIS_SYMBOL_SQUARE_PAASENTO: u32 = 0x332b;
/// 全角 JIS 記号 SQUARE_HEKUTAARU
pub const WIDE_JIS_SYMBOL_SQUARE_HEKUTAARU: u32 = 0x3336;
/// 全角 JIS 記号 SQUARE_PEEZI
pub const WIDE_JIS_SYMBOL_SQUARE_PEEZI: u32 = 0x333b;
/// 全角 JIS 記号 SQUARE_MIRI
pub const WIDE_JIS_SYMBOL_SQUARE_MIRI: u32 = 0x3349;
/// 全角 JIS 記号 SQUARE_MIRIBAARU
pub const WIDE_JIS_SYMBOL_SQUARE_MIRIBAARU: u32 = 0x334a;
/// 全角 JIS 記号 SQUARE_MEETORU
pub const WIDE_JIS_SYMBOL_SQUARE_MEETORU: u32 = 0x334d;
/// 全角 JIS 記号 SQUARE_RITTORU
pub const WIDE_JIS_SYMBOL_SQUARE_RITTORU: u32 = 0x3351;
/// 全角 JIS 記号 SQUARE_WATTO
pub const WIDE_JIS_SYMBOL_SQUARE_WATTO: u32 = 0x3357;
/// 全角 JIS 記号 SQUARE_ERA_NAME_HEISEI
pub const WIDE_JIS_SYMBOL_SQUARE_ERA_NAME_HEISEI: u32 = 0x337b;
/// 全角 JIS 記号 SQUARE_ERA_NAME_SYOUWA
pub const WIDE_JIS_SYMBOL_SQUARE_ERA_NAME_SYOUWA: u32 = 0x337c;
/// 全角 JIS 記号 SQUARE_ERA_NAME_TAISYOU
pub const WIDE_JIS_SYMBOL_SQUARE_ERA_NAME_TAISYOU: u32 = 0x337d;
/// 全角 JIS 記号 SQUARE_ERA_NAME_MEIZI
pub const WIDE_JIS_SYMBOL_SQUARE_ERA_NAME_MEIZI: u32 = 0x337e;
/// 全角 JIS 記号 SQUARE_MG
pub const WIDE_JIS_SYMBOL_SQUARE_MG: u32 = 0x338e;
/// 全角 JIS 記号 SQUARE_KG
pub const WIDE_JIS_SYMBOL_SQUARE_KG: u32 = 0x338f;
/// 全角 JIS 記号 SQUARE_MM
pub const WIDE_JIS_SYMBOL_SQUARE_MM: u32 = 0x339c;
/// 全角 JIS 記号 SQUARE_CM
pub const WIDE_JIS_SYMBOL_SQUARE_CM: u32 = 0x339d;
/// 全角 JIS 記号 SQUARE_KM
pub const WIDE_JIS_SYMBOL_SQUARE_KM: u32 = 0x339e;
/// 全角 JIS 記号 SQUARE_M_SQUARED
pub const WIDE_JIS_SYMBOL_SQUARE_M_SQUARED: u32 = 0x33a1;
/// 全角 JIS 記号 SQUARE_CC
pub const WIDE_JIS_SYMBOL_SQUARE_CC: u32 = 0x33c4;
/// 半角 JIS 記号 SQUARE_HP
pub const NARROW_JIS_SYMBOL_SQUARE_HP: u32 = 0x33cb;
/// 全角 JIS 記号 SQUARE_KK
pub const WIDE_JIS_SYMBOL_SQUARE_KK: u32 = 0x33cd;
/// 全角 JIS 記号 IDEOGRAPH_DOU
pub const WIDE_JIS_SYMBOL_IDEOGRAPH_DOU: u32 = 0x4edd;
/// 半角 JIS 記号 SESAME_DOT
pub const NARROW_JIS_SYMBOL_SESAME_DOT: u32 = 0xfe45;
/// 半角 JIS 記号 WHITE_SESAME_DOT
pub const NARROW_JIS_SYMBOL_WHITE_SESAME_DOT: u32 = 0xfe46;
/// 全角 ASCII文字 記号 EXCLAMATION_MARK
pub const WIDE_ASCII_SYMBOL_EXCLAMATION_MARK: u32 = 0xFF01;
/// 全角 ASCII文字 記号 QUOTATION_MARK
pub const WIDE_ASCII_SYMBOL_QUOTATION_MARK: u32 = 0xFF02;
/// 全角 ASCII文字 記号 NUMBER_SIGN
pub const WIDE_ASCII_SYMBOL_NUMBER_SIGN: u32 = 0xFF03;
/// 全角 ASCII文字 記号 DOLLAR_SIGN
pub const WIDE_ASCII_SYMBOL_DOLLAR_SIGN: u32 = 0xFF04;
/// 全角 ASCII文字 記号 PERCENT_SIGN
pub const WIDE_ASCII_SYMBOL_PERCENT_SIGN: u32 = 0xFF05;
/// 全角 ASCII文字 記号 AMPERSAND
pub const WIDE_ASCII_SYMBOL_AMPERSAND: u32 = 0xFF06;
/// 全角 ASCII文字 記号 APOSTROPHE
pub const WIDE_ASCII_SYMBOL_APOSTROPHE: u32 = 0xFF07;
/// 全角 ASCII文字 記号 LEFT_PARENTHESIS
pub const WIDE_ASCII_SYMBOL_LEFT_PARENTHESIS: u32 = 0xFF08;
/// 全角 ASCII文字 記号 RIGHT_PARENTHESIS
pub const WIDE_ASCII_SYMBOL_RIGHT_PARENTHESIS: u32 = 0xFF09;
/// 全角 ASCII文字 記号 ASTERISK
pub const WIDE_ASCII_SYMBOL_ASTERISK: u32 = 0xFF0A;
/// 全角 ASCII文字 記号 PLUS_SIGN
pub const WIDE_ASCII_SYMBOL_PLUS_SIGN: u32 = 0xFF0B;
/// 全角 ASCII文字 記号 COMMA
pub const WIDE_ASCII_SYMBOL_COMMA: u32 = 0xFF0C;
/// 全角 ASCII文字 記号 HYPHEN-MINUS
pub const WIDE_ASCII_SYMBOL_HYPHEN_MINUS: u32 = 0xFF0D;
/// 全角 ASCII文字 記号 FULL_STOP
pub const WIDE_ASCII_SYMBOL_FULL_STOP: u32 = 0xFF0E;
/// 全角 ASCII文字 記号 SOLIDUS
pub const WIDE_ASCII_SYMBOL_SOLIDUS: u32 = 0xFF0F;
/// 全角 ASCII文字 数値 0
pub const WIDE_ASCII_NUMBER_0: u32 = 0xFF10;
/// 全角 ASCII文字 数値 1
pub const WIDE_ASCII_NUMBER_1: u32 = 0xFF11;
/// 全角 ASCII文字 数値 2
pub const WIDE_ASCII_NUMBER_2: u32 = 0xFF12;
/// 全角 ASCII文字 数値 3
pub const WIDE_ASCII_NUMBER_3: u32 = 0xFF13;
/// 全角 ASCII文字 数値 4
pub const WIDE_ASCII_NUMBER_4: u32 = 0xFF14;
/// 全角 ASCII文字 数値 5
pub const WIDE_ASCII_NUMBER_5: u32 = 0xFF15;
/// 全角 ASCII文字 数値 6
pub const WIDE_ASCII_NUMBER_6: u32 = 0xFF16;
/// 全角 ASCII文字 数値 7
pub const WIDE_ASCII_NUMBER_7: u32 = 0xFF17;
/// 全角 ASCII文字 数値 8
pub const WIDE_ASCII_NUMBER_8: u32 = 0xFF18;
/// 全角 ASCII文字 数値 9
pub const WIDE_ASCII_NUMBER_9: u32 = 0xFF19;
/// 全角 ASCII文字 記号 COLON
pub const WIDE_ASCII_SYMBOL_COLON: u32 = 0xFF1A;
/// 全角 ASCII文字 記号 SEMICOLON
pub const WIDE_ASCII_SYMBOL_SEMICOLON: u32 = 0xFF1B;
/// 全角 ASCII文字 記号 LESS-THAN_SIGN
pub const WIDE_ASCII_SYMBOL_LESS_THAN_SIGN: u32 = 0xFF1C;
/// 全角 ASCII文字 記号 EQUALS_SIGN
pub const WIDE_ASCII_SYMBOL_EQUALS_SIGN: u32 = 0xFF1D;
/// 全角 ASCII文字 記号 GREATER-THAN_SIGN
pub const WIDE_ASCII_SYMBOL_GREATER_THAN_SIGN: u32 = 0xFF1E;
/// 全角 ASCII文字 記号 QUESTION_MARK
pub const WIDE_ASCII_SYMBOL_QUESTION_MARK: u32 = 0xFF1F;
/// 全角 ASCII文字 記号 COMMERCIAL_AT
pub const WIDE_ASCII_SYMBOL_COMMERCIAL_AT: u32 = 0xFF20;
/// 全角 ASCII文字 アルファベット大文字 A
pub const WIDE_ASCII_LATIN_UPPER_CASE_A: u32 = 0xFF21;
/// 全角 ASCII文字 アルファベット大文字 B
pub const WIDE_ASCII_LATIN_UPPER_CASE_B: u32 = 0xFF22;
/// 全角 ASCII文字 アルファベット大文字 C
pub const WIDE_ASCII_LATIN_UPPER_CASE_C: u32 = 0xFF23;
/// 全角 ASCII文字 アルファベット大文字 D
pub const WIDE_ASCII_LATIN_UPPER_CASE_D: u32 = 0xFF24;
/// 全角 ASCII文字 アルファベット大文字 E
pub const WIDE_ASCII_LATIN_UPPER_CASE_E: u32 = 0xFF25;
/// 全角 ASCII文字 アルファベット大文字 F
pub const WIDE_ASCII_LATIN_UPPER_CASE_F: u32 = 0xFF26;
/// 全角 ASCII文字 アルファベット大文字 G
pub const WIDE_ASCII_LATIN_UPPER_CASE_G: u32 = 0xFF27;
/// 全角 ASCII文字 アルファベット大文字 H
pub const WIDE_ASCII_LATIN_UPPER_CASE_H: u32 = 0xFF28;
/// 全角 ASCII文字 アルファベット大文字 I
pub const WIDE_ASCII_LATIN_UPPER_CASE_I: u32 = 0xFF29;
/// 全角 ASCII文字 アルファベット大文字 J
pub const WIDE_ASCII_LATIN_UPPER_CASE_J: u32 = 0xFF2A;
/// 全角 ASCII文字 アルファベット大文字 K
pub const WIDE_ASCII_LATIN_UPPER_CASE_K: u32 = 0xFF2B;
/// 全角 ASCII文字 アルファベット大文字 L
pub const WIDE_ASCII_LATIN_UPPER_CASE_L: u32 = 0xFF2C;
/// 全角 ASCII文字 アルファベット大文字 M
pub const WIDE_ASCII_LATIN_UPPER_CASE_M: u32 = 0xFF2D;
/// 全角 ASCII文字 アルファベット大文字 N
pub const WIDE_ASCII_LATIN_UPPER_CASE_N: u32 = 0xFF2E;
/// 全角 ASCII文字 アルファベット大文字 O
pub const WIDE_ASCII_LATIN_UPPER_CASE_O: u32 = 0xFF2F;
/// 全角 ASCII文字 アルファベット大文字 P
pub const WIDE_ASCII_LATIN_UPPER_CASE_P: u32 = 0xFF30;
/// 全角 ASCII文字 アルファベット大文字 Q
pub const WIDE_ASCII_LATIN_UPPER_CASE_Q: u32 = 0xFF31;
/// 全角 ASCII文字 アルファベット大文字 R
pub const WIDE_ASCII_LATIN_UPPER_CASE_R: u32 = 0xFF32;
/// 全角 ASCII文字 アルファベット大文字 S
pub const WIDE_ASCII_LATIN_UPPER_CASE_S: u32 = 0xFF33;
/// 全角 ASCII文字 アルファベット大文字 T
pub const WIDE_ASCII_LATIN_UPPER_CASE_T: u32 = 0xFF34;
/// 全角 ASCII文字 アルファベット大文字 U
pub const WIDE_ASCII_LATIN_UPPER_CASE_U: u32 = 0xFF35;
/// 全角 ASCII文字 アルファベット大文字 V
pub const WIDE_ASCII_LATIN_UPPER_CASE_V: u32 = 0xFF36;
/// 全角 ASCII文字 アルファベット大文字 W
pub const WIDE_ASCII_LATIN_UPPER_CASE_W: u32 = 0xFF37;
/// 全角 ASCII文字 アルファベット大文字 X
pub const WIDE_ASCII_LATIN_UPPER_CASE_X: u32 = 0xFF38;
/// 全角 ASCII文字 アルファベット大文字 Y
pub const WIDE_ASCII_LATIN_UPPER_CASE_Y: u32 = 0xFF39;
/// 全角 ASCII文字 アルファベット大文字 Z
pub const WIDE_ASCII_LATIN_UPPER_CASE_Z: u32 = 0xFF3A;
/// 全角 ASCII文字 記号 LEFT_SQUARE_BRACKET
pub const WIDE_ASCII_SYMBOL_LEFT_SQUARE_BRACKET: u32 = 0xFF3B;
/// 全角 ASCII文字 記号 REVERSE_SOLIDUS
pub const WIDE_ASCII_SYMBOL_REVERSE_SOLIDUS: u32 = 0xFF3C;
/// 全角 ASCII文字 記号 RIGHT_SQUARE_BRACKET
pub const WIDE_ASCII_SYMBOL_RIGHT_SQUARE_BRACKET: u32 = 0xFF3D;
/// 全角 ASCII文字 記号 CIRCUMFLEX_ACCENT
pub const WIDE_ASCII_SYMBOL_CIRCUMFLEX_ACCENT: u32 = 0xFF3E;
/// 全角 ASCII文字 記号 LOW_LINE
pub const WIDE_ASCII_SYMBOL_LOW_LINE: u32 = 0xFF3F;
/// 全角 ASCII文字 記号 GRAVE_ACCENT
pub const WIDE_ASCII_SYMBOL_GRAVE_ACCENT: u32 = 0xFF40;
/// 全角 ASCII文字 アルファベット小文字 A
pub const WIDE_ASCII_LATIN_LOWER_CASE_A: u32 = 0xFF41;
/// 全角 ASCII文字 アルファベット小文字 B
pub const WIDE_ASCII_LATIN_LOWER_CASE_B: u32 = 0xFF42;
/// 全角 ASCII文字 アルファベット小文字 C
pub const WIDE_ASCII_LATIN_LOWER_CASE_C: u32 = 0xFF43;
/// 全角 ASCII文字 アルファベット小文字 D
pub const WIDE_ASCII_LATIN_LOWER_CASE_D: u32 = 0xFF44;
/// 全角 ASCII文字 アルファベット小文字 E
pub const WIDE_ASCII_LATIN_LOWER_CASE_E: u32 = 0xFF45;
/// 全角 ASCII文字 アルファベット小文字 F
pub const WIDE_ASCII_LATIN_LOWER_CASE_F: u32 = 0xFF46;
/// 全角 ASCII文字 アルファベット小文字 G
pub const WIDE_ASCII_LATIN_LOWER_CASE_G: u32 = 0xFF47;
/// 全角 ASCII文字 アルファベット小文字 H
pub const WIDE_ASCII_LATIN_LOWER_CASE_H: u32 = 0xFF48;
/// 全角 ASCII文字 アルファベット小文字 I
pub const WIDE_ASCII_LATIN_LOWER_CASE_I: u32 = 0xFF49;
/// 全角 ASCII文字 アルファベット小文字 J
pub const WIDE_ASCII_LATIN_LOWER_CASE_J: u32 = 0xFF4A;
/// 全角 ASCII文字 アルファベット小文字 K
pub const WIDE_ASCII_LATIN_LOWER_CASE_K: u32 = 0xFF4B;
/// 全角 ASCII文字 アルファベット小文字 L
pub const WIDE_ASCII_LATIN_LOWER_CASE_L: u32 = 0xFF4C;
/// 全角 ASCII文字 アルファベット小文字 M
pub const WIDE_ASCII_LATIN_LOWER_CASE_M: u32 = 0xFF4D;
/// 全角 ASCII文字 アルファベット小文字 N
pub const WIDE_ASCII_LATIN_LOWER_CASE_N: u32 = 0xFF4E;
/// 全角 ASCII文字 アルファベット小文字 O
pub const WIDE_ASCII_LATIN_LOWER_CASE_O: u32 = 0xFF4F;
/// 全角 ASCII文字 アルファベット小文字 P
pub const WIDE_ASCII_LATIN_LOWER_CASE_P: u32 = 0xFF50;
/// 全角 ASCII文字 アルファベット小文字 Q
pub const WIDE_ASCII_LATIN_LOWER_CASE_Q: u32 = 0xFF51;
/// 全角 ASCII文字 アルファベット小文字 R
pub const WIDE_ASCII_LATIN_LOWER_CASE_R: u32 = 0xFF52;
/// 全角 ASCII文字 アルファベット小文字 S
pub const WIDE_ASCII_LATIN_LOWER_CASE_S: u32 = 0xFF53;
/// 全角 ASCII文字 アルファベット小文字 T
pub const WIDE_ASCII_LATIN_LOWER_CASE_T: u32 = 0xFF54;
/// 全角 ASCII文字 アルファベット小文字 U
pub const WIDE_ASCII_LATIN_LOWER_CASE_U: u32 = 0xFF55;
/// 全角 ASCII文字 アルファベット小文字 V
pub const WIDE_ASCII_LATIN_LOWER_CASE_V: u32 = 0xFF56;
/// 全角 ASCII文字 アルファベット小文字 W
pub const WIDE_ASCII_LATIN_LOWER_CASE_W: u32 = 0xFF57;
/// 全角 ASCII文字 アルファベット小文字 X
pub const WIDE_ASCII_LATIN_LOWER_CASE_X: u32 = 0xFF58;
/// 全角 ASCII文字 アルファベット小文字 Y
pub const WIDE_ASCII_LATIN_LOWER_CASE_Y: u32 = 0xFF59;
/// 全角 ASCII文字 アルファベット小文字 Z
pub const WIDE_ASCII_LATIN_LOWER_CASE_Z: u32 = 0xFF5A;
/// 全角 ASCII文字 記号 LEFT_CURLY_BRACKET
pub const WIDE_ASCII_SYMBOL_LEFT_CURLY_BRACKET: u32 = 0xFF5B;
/// 全角 ASCII文字 記号 VERTICAL_LINE
pub const WIDE_ASCII_SYMBOL_VERTICAL_LINE: u32 = 0xFF5C;
/// 全角 ASCII文字 記号 RIGHT_CURLY_BRACKET
pub const WIDE_ASCII_SYMBOL_RIGHT_CURLY_BRACKET: u32 = 0xFF5D;
/// 全角 ASCII文字 記号 TILDE
pub const WIDE_ASCII_SYMBOL_TILDE: u32 = 0xFF5E;
/// 半角 JIS 記号 LEFT_WHITE_PARENTHESIS
pub const NARROW_JIS_SYMBOL_LEFT_WHITE_PARENTHESIS: u32 = 0xFF5F;
/// 半角 JIS 記号 RIGHT_WHITE_PARENTHESIS
pub const NARROW_JIS_SYMBOL_RIGHT_WHITE_PARENTHESIS: u32 = 0xFF60;
/// 半角 JIS 記号 IDEOGRAPHIC_FULL_STOP
pub const NARROW_JIS_SYMBOL_IDEOGRAPHIC_FULL_STOP: u32 = 0xFF61;
/// 半角 JIS 記号 LEFT_CORNER_BRACKET
pub const NARROW_JIS_SYMBOL_LEFT_CORNER_BRACKET: u32 = 0xFF62;
/// 半角 JIS 記号 RIGHT_CORNER_BRACKET
pub const NARROW_JIS_SYMBOL_RIGHT_CORNER_BRACKET: u32 = 0xFF63;
/// 半角 JIS 記号 IDEOGRAPHIC_COMMA
pub const NARROW_JIS_SYMBOL_IDEOGRAPHIC_COMMA: u32 = 0xFF64;
/// 半角 JIS 記号 KATAKANA_MIDDLE_DOT
pub const NARROW_JIS_SYMBOL_KATAKANA_MIDDLE_DOT: u32 = 0xFF65;
/// 半角 かな文字 カタカナ WO
pub const NARROW_KANA_KATAKANA_WO: u32 = 0xFF66;
/// 半角 かな文字 カタカナ SMALL_A
pub const NARROW_KANA_KATAKANA_SMALL_A: u32 = 0xFF67;
/// 半角 かな文字 カタカナ SMALL_I
pub const NARROW_KANA_KATAKANA_SMALL_I: u32 = 0xFF68;
/// 半角 かな文字 カタカナ SMALL_U
pub const NARROW_KANA_KATAKANA_SMALL_U: u32 = 0xFF69;
/// 半角 かな文字 カタカナ SMALL_E
pub const NARROW_KANA_KATAKANA_SMALL_E: u32 = 0xFF6A;
/// 半角 かな文字 カタカナ SMALL_O
pub const NARROW_KANA_KATAKANA_SMALL_O: u32 = 0xFF6B;
/// 半角 かな文字 カタカナ SMALL_YA
pub const NARROW_KANA_KATAKANA_SMALL_YA: u32 = 0xFF6C;
/// 半角 かな文字 カタカナ SMALL_YU
pub const NARROW_KANA_KATAKANA_SMALL_YU: u32 = 0xFF6D;
/// 半角 かな文字 カタカナ SMALL_YO
pub const NARROW_KANA_KATAKANA_SMALL_YO: u32 = 0xFF6E;
/// 半角 かな文字 カタカナ SMALL_TU
pub const NARROW_KANA_KATAKANA_SMALL_TU: u32 = 0xFF6F;
/// 半角 JIS 記号 PROLONGED_SOUND_MARK
pub const NARROW_JIS_SYMBOL_PROLONGED_SOUND_MARK: u32 = 0xFF70;
/// 半角 かな文字 カタカナ A
pub const NARROW_KANA_KATAKANA_A: u32 = 0xFF71;
/// 半角 かな文字 カタカナ I
pub const NARROW_KANA_KATAKANA_I: u32 = 0xFF72;
/// 半角 かな文字 カタカナ U
pub const NARROW_KANA_KATAKANA_U: u32 = 0xFF73;
/// 半角 かな文字 カタカナ E
pub const NARROW_KANA_KATAKANA_E: u32 = 0xFF74;
/// 半角 かな文字 カタカナ O
pub const NARROW_KANA_KATAKANA_O: u32 = 0xFF75;
/// 半角 かな文字 カタカナ KA
pub const NARROW_KANA_KATAKANA_KA: u32 = 0xFF76;
/// 半角 かな文字 カタカナ KI
pub const NARROW_KANA_KATAKANA_KI: u32 = 0xFF77;
/// 半角 かな文字 カタカナ KU
pub const NARROW_KANA_KATAKANA_KU: u32 = 0xFF78;
/// 半角 かな文字 カタカナ KE
pub const NARROW_KANA_KATAKANA_KE: u32 = 0xFF79;
/// 半角 かな文字 カタカナ KO
pub const NARROW_KANA_KATAKANA_KO: u32 = 0xFF7A;
/// 半角 かな文字 カタカナ SA
pub const NARROW_KANA_KATAKANA_SA: u32 = 0xFF7B;
/// 半角 かな文字 カタカナ SI
pub const NARROW_KANA_KATAKANA_SI: u32 = 0xFF7C;
/// 半角 かな文字 カタカナ SU
pub const NARROW_KANA_KATAKANA_SU: u32 = 0xFF7D;
/// 半角 かな文字 カタカナ SE
pub const NARROW_KANA_KATAKANA_SE: u32 = 0xFF7E;
/// 半角 かな文字 カタカナ SO
pub const NARROW_KANA_KATAKANA_SO: u32 = 0xFF7F;
/// 半角 かな文字 カタカナ TA
pub const NARROW_KANA_KATAKANA_TA: u32 = 0xFF80;
/// 半角 かな文字 カタカナ TI
pub const NARROW_KANA_KATAKANA_TI: u32 = 0xFF81;
/// 半角 かな文字 カタカナ TU
pub const NARROW_KANA_KATAKANA_TU: u32 = 0xFF82;
/// 半角 かな文字 カタカナ TE
pub const NARROW_KANA_KATAKANA_TE: u32 = 0xFF83;
/// 半角 かな文字 カタカナ TO
pub const NARROW_KANA_KATAKANA_TO: u32 = 0xFF84;
/// 半角 かな文字 カタカナ NA
pub const NARROW_KANA_KATAKANA_NA: u32 = 0xFF85;
/// 半角 かな文字 カタカナ NI
pub const NARROW_KANA_KATAKANA_NI: u32 = 0xFF86;
/// 半角 かな文字 カタカナ NU
pub const NARROW_KANA_KATAKANA_NU: u32 = 0xFF87;
/// 半角 かな文字 カタカナ NE
pub const NARROW_KANA_KATAKANA_NE: u32 = 0xFF88;
/// 半角 かな文字 カタカナ NO
pub const NARROW_KANA_KATAKANA_NO: u32 = 0xFF89;
/// 半角 かな文字 カタカナ HA
pub const NARROW_KANA_KATAKANA_HA: u32 = 0xFF8A;
/// 半角 かな文字 カタカナ HI
pub const NARROW_KANA_KATAKANA_HI: u32 = 0xFF8B;
/// 半角 かな文字 カタカナ HU
pub const NARROW_KANA_KATAKANA_HU: u32 = 0xFF8C;
/// 半角 かな文字 カタカナ HE
pub const NARROW_KANA_KATAKANA_HE: u32 = 0xFF8D;
/// 半角 かな文字 カタカナ HO
pub const NARROW_KANA_KATAKANA_HO: u32 = 0xFF8E;
/// 半角 かな文字 カタカナ MA
pub const NARROW_KANA_KATAKANA_MA: u32 = 0xFF8F;
/// 半角 かな文字 カタカナ MI
pub const NARROW_KANA_KATAKANA_MI: u32 = 0xFF90;
/// 半角 かな文字 カタカナ MU
pub const NARROW_KANA_KATAKANA_MU: u32 = 0xFF91;
/// 半角 かな文字 カタカナ ME
pub const NARROW_KANA_KATAKANA_ME: u32 = 0xFF92;
/// 半角 かな文字 カタカナ MO
pub const NARROW_KANA_KATAKANA_MO: u32 = 0xFF93;
/// 半角 かな文字 カタカナ YA
pub const NARROW_KANA_KATAKANA_YA: u32 = 0xFF94;
/// 半角 かな文字 カタカナ YU
pub const NARROW_KANA_KATAKANA_YU: u32 = 0xFF95;
/// 半角 かな文字 カタカナ YO
pub const NARROW_KANA_KATAKANA_YO: u32 = 0xFF96;
/// 半角 かな文字 カタカナ RA
pub const NARROW_KANA_KATAKANA_RA: u32 = 0xFF97;
/// 半角 かな文字 カタカナ RI
pub const NARROW_KANA_KATAKANA_RI: u32 = 0xFF98;
/// 半角 かな文字 カタカナ RU
pub const NARROW_KANA_KATAKANA_RU: u32 = 0xFF99;
/// 半角 かな文字 カタカナ RE
pub const NARROW_KANA_KATAKANA_RE: u32 = 0xFF9A;
/// 半角 かな文字 カタカナ RO
pub const NARROW_KANA_KATAKANA_RO: u32 = 0xFF9B;
/// 半角 かな文字 カタカナ WA
pub const NARROW_KANA_KATAKANA_WA: u32 = 0xFF9C;
/// 半角 かな文字 カタカナ N
pub const NARROW_KANA_KATAKANA_N: u32 = 0xFF9D;
/// 半角 JIS 記号 KATAKANA_VOICED_SOUND_MARK
pub const NARROW_JIS_SYMBOL_KATAKANA_VOICED_SOUND_MARK: u32 = 0xFF9E;
/// 半角 JIS 記号 KATAKANA_SEMI-VOICED_SOUND_MARK
pub const NARROW_JIS_SYMBOL_KATAKANA_SEMI_VOICED_SOUND_MARK: u32 = 0xFF9F;
/// 全角 JIS 記号 CENT_SIGN
pub const WIDE_JIS_SYMBOL_CENT_SIGN: u32 = 0xFFE0;
/// 全角 JIS 記号 POUND_SIGN
pub const WIDE_JIS_SYMBOL_POUND_SIGN: u32 = 0xFFE1;
/// 全角 JIS 記号 NOT_SIGN
pub const WIDE_JIS_SYMBOL_NOT_SIGN: u32 = 0xFFE2;
/// 全角 JIS 記号 MACRON
pub const WIDE_JIS_SYMBOL_MACRON: u32 = 0xFFE3;
/// 全角 JIS 記号 BROKEN_BAR
pub const WIDE_JIS_SYMBOL_BROKEN_BAR: u32 = 0xFFE4;
/// 全角 JIS 記号 YEN_SIGN
pub const WIDE_JIS_SYMBOL_YEN_SIGN: u32 = 0xFFE5;
/// 全角 JIS 記号 WON_SIGN
pub const WIDE_JIS_SYMBOL_WON_SIGN: u32 = 0xFFE6;
/// 半角 JIS 記号 FORMS_LIGHT_VERTICAL
pub const NARROW_JIS_SYMBOL_FORMS_LIGHT_VERTICAL: u32 = 0xFFE8;
/// 半角 JIS 記号 LEFTWARDS_ARROW
pub const NARROW_JIS_SYMBOL_LEFTWARDS_ARROW: u32 = 0xFFE9;
/// 半角 JIS 記号 UPWARDS_ARROW
pub const NARROW_JIS_SYMBOL_UPWARDS_ARROW: u32 = 0xFFEA;
/// 半角 JIS 記号 RIGHTWARDS_ARROW
pub const NARROW_JIS_SYMBOL_RIGHTWARDS_ARROW: u32 = 0xFFEB;
/// 半角 JIS 記号 DOWNWARDS_ARROW
pub const NARROW_JIS_SYMBOL_DOWNWARDS_ARROW: u32 = 0xFFEC;
/// 半角 JIS 記号 BLACK_SQUARE
pub const NARROW_JIS_SYMBOL_BLACK_SQUARE: u32 = 0xFFED;
/// 半角 JIS 記号 WHITE_CIRCLE
pub const NARROW_JIS_SYMBOL_WHITE_CIRCLE: u32 = 0xFFEE;
